
function TermsSpiralsCrosstrainingByCondition(subjId, attentionCond, f, p, problem)

% INPUTS: subjId
%         attentionCond ('HueCond' or 'LumCond')
%         f             (struct of paths)
%         p             (struct of decoding parameters)
%
% Available labels: raster_labels.triggers     
%                   raster_labels.stimNames     
%                   raster_labels.attentionCond 
%                   raster_labels.hue           
%                   raster_labels.lum           

% % stimNames = {'az45sat75elev20','az45sat75elev340','az135sat75elev20',...
% %              'az135sat75elev340','az225sat75elev20','az225sat75elev340',...
% %              'az315sat75elev20','az315sat75elev340', 'green', 'blue'};

lumOffset = 0;
if strcmp(attentionCond, 'LumCond')
    lumOffset = 50
end

elev20Spirals  = [3, 5]; %light green + blue
elev340Spirals = [4, 6]; %dark green + blue
colorTerms = [9,10]; %[green blue]

the_labels_to_use = 'triggers';

if nargin > 4

	switch problem
		case 1
			% Problem #1a: Train terms / Test low lum elev20
			fileId = ['TrainTermsTestElev20_' attentionCond]
			trainTrigs = convertToInvarianceLabelFormat(colorTerms + lumOffset);
			testTrigs  = convertToInvarianceLabelFormat(elev20Spirals + lumOffset);
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		
		case 2
			% Problem #1b: Train terms / Test high lum elev340
			fileId = ['TrainTermsTestElev340_' attentionCond]
			trainTrigs = convertToInvarianceLabelFormat(colorTerms + lumOffset);
			testTrigs  = convertToInvarianceLabelFormat(elev340Spirals + lumOffset);
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

		case 3
			% Problem #2a: Train low lum elev20/ Test spirals
			fileId = ['TrainElev20TestTerms_' attentionCond]
			trainTrigs = convertToInvarianceLabelFormat(elev20Spirals + lumOffset);
			testTrigs  = convertToInvarianceLabelFormat(colorTerms + lumOffset);
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

		case 4
			% Problem #2b: Train high lum elev340/ Test spirals
			fileId = ['TrainElev340TestTerms_' attentionCond]
			trainTrigs = convertToInvarianceLabelFormat(elev340Spirals + lumOffset);
			testTrigs  = convertToInvarianceLabelFormat(colorTerms + lumOffset);
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

	end

else

	% Problem #1a: Train terms / Test low lum elev20
	fileId = ['TrainTermsTestElev20_' attentionCond];
	trainTrigs = convertToInvarianceLabelFormat(colorTerms + lumOffset);
	testTrigs  = convertToInvarianceLabelFormat(elev20Spirals + lumOffset);
	runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

	% Problem #1b: Train terms / Test high lum elev340
	fileId = ['TrainTermsTestElev340_' attentionCond];
	trainTrigs = convertToInvarianceLabelFormat(colorTerms + lumOffset);
	testTrigs  = convertToInvarianceLabelFormat(elev340Spirals + lumOffset);
	runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

	% Problem #2a: Train low lum elev20/ Test spirals
	fileId = ['TrainElev20TestTerms_' attentionCond];
	trainTrigs = convertToInvarianceLabelFormat(elev20Spirals + lumOffset);
	testTrigs  = convertToInvarianceLabelFormat(colorTerms + lumOffset);
	runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

	% Problem #2b: Train high lum elev340/ Test spirals
	fileId = ['TrainElev340TestTerms_' attentionCond];
	trainTrigs = convertToInvarianceLabelFormat(elev340Spirals + lumOffset);
	testTrigs  = convertToInvarianceLabelFormat(colorTerms + lumOffset);
	runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)

end

end