
function decodeHueWithinALuminanceByConditionBinaryAll(subjId, attentionCond, f, p, nullOpt)

% INPUTS: subjId
%         attentionCond ('HueCond' or 'LumCond')
%         f             (struct of paths)
%         p             (struct of decoding parameters)
%         nullOpt       (1 = do null decoding runs)
%
% Available labels: raster_labels.triggers     
%                   raster_labels.stimNames     
%                   raster_labels.attentionCond 
%                   raster_labels.hue           
%                   raster_labels.lum           

if p.longwindow == 1
	timewindowStr = ['_' num2str(timewindow),'ms2'];
else
	timewindowStr = [];
end

disp('decodeHueWithinALuminanceByConditionBinary')

lumOffset = 0;
if strcmp(attentionCond, 'LumCond')
    lumOffset = 50
end

hueNames = {'45','45', '135','135', '225', '225', '315', '315'};
elevNames = {'20','340'};

% 1=lPink, 2=dPink, 3=lBlue, 4=dBlue, 5=lGreen,6=dGreen, 7=lOrange,
% 8=dOrange
pairsToDecode = {[1,2;5,6],[1,2;7,8],[3,4;7,8],[3,4;5,6],[1,2;3,4],[5,6;7,8]};

the_labels_to_use = 'triggers';

if isfield(p,'huePair')
	disp(['DECODING HUE PAIR: ' num2str(p.huePair)])
	pairToDecode = pairsToDecode{p.huePair};
	if isfield(p,'elev')
		elevToDecode = pairToDecode(:,p.elev)'
		elev20name = ['Az' hueNames{elevToDecode(1)} 'Az' hueNames{elevToDecode(2)}]
		
		fileId1 = ['HueWithinElev' elevNames{p.elev} elev20name '_' attentionCond timewindowStr];
		trainTrigs = elevToDecode + lumOffset
		testTrigs  = trainTrigs
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)  
		else
			disp('Starting run decoding')
			runDecoding(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end

    else 
        % Problem #2: Hue Within Elev 340 spirals
		elev20toDecode = pairToDecode(:,1)'
		elev20name = ['Az' hueNames{elev20toDecode(1)} 'Az' hueNames{elev20toDecode(2)}]
		fileId1 = ['HueWithinElev20' elev20name '_' attentionCond timewindowStr];
		trainTrigs = elev20toDecode + lumOffset;
		testTrigs  = trainTrigs;
		
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)  
		else
			runDecoding(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        end

		% Problem #2: Hue Within Elev 340 spirals
		elev340toDecode = pairToDecode(:,2)'
		elev340name = ['Az' hueNames{elev340toDecode(1)} 'Az' hueNames{elev340toDecode(2)}]
		fileId2 = ['HueWithinElev340' elev340name '_' attentionCond timewindowStr];
		trainTrigs = elev340toDecode + lumOffset;
		testTrigs  = trainTrigs;
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)  
		else
			runDecoding(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end
	end
else
	disp('Starting loop')
	for ind = 1:numel(pairsToDecode)
		pairToDecode = pairsToDecode{ind}
		
        % Problem #1: Hue within Elev 20 spirals
		elev20toDecode = pairToDecode(:,1)'
		elev20name = ['Az' hueNames{elev20toDecode(1)} 'Az' hueNames{elev20toDecode(2)}]
		fileId1 = ['HueWithinElev20' elev20name '_' attentionCond timewindowStr];
		trainTrigs = elev20toDecode + lumOffset;
		testTrigs  = trainTrigs; 
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)        
        else
			disp('Starting run decoding')
			runDecoding(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        end

        % Problem #2: Hue within Elev 340 spirals
		elev340toDecode = pairToDecode(:,2)'
		elev340name = ['Az' hueNames{elev340toDecode(1)} 'Az' hueNames{elev340toDecode(2)}]
		fileId2 = ['HueWithinElev340' elev340name '_' attentionCond timewindowStr];
		trainTrigs = elev340toDecode + lumOffset;
		testTrigs  = trainTrigs;
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
        else
            disp('Starting run decoding')
			runDecoding(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end

	end
end
end
