
function decodeLuminanceWithinAHueByCondition(subjId, attentionCond, f, p, nullOpt)

% INPUTS: subjId
%         attentionCond ('HueCond' or 'LumCond')
%         f             (struct of paths)
%         p             (struct of decoding parameters)
%         nullOpt       (1 = with permutation tests)
%
% Available labels: raster_labels.triggers     
%                   raster_labels.stimNames     
%                   raster_labels.attentionCond 
%                   raster_labels.hue           
%                   raster_labels.lum           

if p.longwindow == 1
	timewindowStr = ['_' num2str(timewindow),'ms2'];
else
	timewindowStr = [];
end

lumOffset = 0;
if strcmp(attentionCond, 'LumCond')
    lumOffset = 50
end

huePairs = [1, 2; 3, 4; 5, 6; 7, 8]; % col 1 = elev20, col2 = elev340

hueNames = {'45', '135', '225', '315'};

the_labels_to_use = 'triggers';

if isfield(p,'huePair')
	i = p.huePair;
	disp(['Decoding within Hue Pair #' num2str(i) '/' num2str(size(huePairs, 1))])
	fileId = ['LumWithinAz' hueNames{i} '_' attentionCond timewindowStr];
	trainTrigs = huePairs(i, :) + lumOffset;
	testTrigs  = trainTrigs;
	if p.powerAnalysis == 1
		runDecodingForPowerAnalysis(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
    elseif nullOpt == 1
		runSignificanceTests(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
	else
		runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
    end

else
	% Decode lum within each hue pair
	for i = 1 : size(huePairs, 1)
		disp(['Decoding within Hue Pair #' num2str(i) '/' num2str(size(huePairs, 1))])
		fileId = ['LumWithinAz' hueNames{i} '_' attentionCond timewindowStr];
		trainTrigs = huePairs(i, :) + lumOffset;
		testTrigs  = trainTrigs;
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
            runSignificanceTests(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end

	end
end
end
