
function generalizeHueAcrossLuminancesByConditionBinaryAll(subjId, attentionCond, f, p, nullOpt)

% INPUTS: subjId
%         attentionCond ('HueCond' or 'LumCond')
%         f             (struct of paths)
%         p             (struct of decoding parameters)
%         nullOpt       (1 = with permutation tests)
%
% Available labels: raster_labels.triggers
%                   raster_labels.stimNames
%                   raster_labels.attentionCond
%                   raster_labels.hue
%                   raster_labels.lum

if p.longwindow == 1
	timewindowStr = ['_' num2str(timewindow),'ms2']
else
	timewindowStr = []
end

lumOffset = 0;
if strcmp(attentionCond, 'LumCond')
    lumOffset = 50
end

hueNames = {'45','45', '135','135', '225', '225', '315', '315'};
elevNames = {'20','340'};

pairsToDecode = {[1,2;5,6],[1,2;7,8],[3,4;7,8],[3,4;5,6],[1,2;3,4],[5,6;7,8]};

the_labels_to_use = 'triggers';

if isfield(p,'huePair')
	pairToDecode = pairsToDecode{p.huePair};
	if isfield(p,'trainElev')
		trainElevPair = pairToDecode(:,p.trainElev)'
		
		testElev = (p.trainElev-2)*-1 + 1;
		testElevPair = pairToDecode(:,testElev)'
		
		huesToDecode = ['Az' hueNames{trainElevPair(1)} 'Az' hueNames{trainElevPair(2)}]
		
		% Problem #1: Train elev20 / Test elev340
		fileId = ['GenHueAcrossLumsTrainElev' elevNames{p.trainElev} huesToDecode '_' attentionCond timewindowStr]
		trainTrigs = convertToInvarianceLabelFormat(trainElevPair + lumOffset)
		testTrigs  = convertToInvarianceLabelFormat(testElevPair + lumOffset)
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end
	
	else
		elev20toDecode = pairToDecode(:,1)'
		elev340toDecode = pairToDecode(:,2)'
		elev20name = ['Az' hueNames{elev20toDecode(1)} 'Az' hueNames{elev20toDecode(2)}]
		elev340name = ['Az' hueNames{elev340toDecode(1)} 'Az' hueNames{elev340toDecode(2)}]
		
		% Problem #1: Train elev20 / Test elev340
		fileId1 = ['GenHueAcrossLumsTrainElev20' elev20name '_' attentionCond timewindowStr]
		trainTrigs = convertToInvarianceLabelFormat(elev20toDecode + lumOffset);
		testTrigs  = convertToInvarianceLabelFormat(elev340toDecode + lumOffset);
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end
		
		% Problem #2: Train elev340 / Test elev20
		fileId2 = ['GenHueAcrossLumsTrainElev340' elev20name '_'  attentionCond timewindowStr]
		trainTrigs = convertToInvarianceLabelFormat(elev340toDecode + lumOffset);
		testTrigs  = convertToInvarianceLabelFormat(elev20toDecode + lumOffset);
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end
	end
	
else
	for ind = 1:numel(pairsToDecode)
		pairToDecode = pairsToDecode{ind}
		elev20toDecode = pairToDecode(:,1)'
		elev340toDecode = pairToDecode(:,2)'
		elev20name = ['Az' hueNames{elev20toDecode(1)} 'Az' hueNames{elev20toDecode(2)}]
		elev340name = ['Az' hueNames{elev340toDecode(1)} 'Az' hueNames{elev340toDecode(2)}]
		
		% Problem #1: Train elev20 / Test elev340
		fileId1 = ['GenHueAcrossLumsTrainElev20' elev20name '_' attentionCond timewindowStr]
		trainTrigs = convertToInvarianceLabelFormat(elev20toDecode + lumOffset)
		testTrigs  = convertToInvarianceLabelFormat(elev340toDecode + lumOffset)
		if p.powerAnalysis == 1
			disp('running power analysis')
			runDecodingForPowerAnalysis(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId1, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end
		
		% Problem #2: Train elev340 / Test elev20
		fileId2 = ['GenHueAcrossLumsTrainElev340' elev20name '_'  attentionCond timewindowStr]
		trainTrigs = convertToInvarianceLabelFormat(elev340toDecode + lumOffset);
		testTrigs  = convertToInvarianceLabelFormat(elev20toDecode + lumOffset);
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId2, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end

	end
end
end
