function generalizeLumAcrossHuesByCondition(subjId, attentionCond, f, p, nullOpt)

% INPUTS: subjId
%         attentionCond ('HueCond' or 'LumCond')
%         f             (struct of paths)
%         p             (struct of decoding parameters)
%         nullOpt       (1 = with permutation tests)
%
% Available labels: raster_labels.triggers     
%                   raster_labels.stimNames     
%                   raster_labels.attentionCond 
%                   raster_labels.hue           
%                   raster_labels.lum           

if p.longwindow == 1
	timewindowStr = ['_' num2str(timewindow),'ms2'];
else
	timewindowStr = [];
end

lumOffset = 0;
if strcmp(attentionCond, 'LumCond')
    lumOffset = 50
end

hueNames = {'45', '135', '225', '315'};

trainHues = {'45', '135', '225', '315'};
testHues = {'45', '135', '225', '315'};
trainHuePairs = [1,2; 3,4; 5,6; 7,8]; % col 1 = elev20, col2 = elev340
testHuePairs = [1,2; 3,4; 5,6; 7,8]; % col 1 = elev20, col2 = elev340

the_labels_to_use = 'triggers';

if isfield(p,'trainHue')
	i = p.trainHue;
	j = p.testHue;
	disp(['Decoding...Training Hue Pair #' num2str(i) ', Testing Hue Pair #' num2str(j)])
	fileId = ['GenLumAcrossHuesTrainAz' trainHues{i} 'TestAz' testHues{j} '_' attentionCond timewindowStr];
	trainTrigs = convertToInvarianceLabelFormat(trainHuePairs(i, :) + lumOffset);
	testTrigs  = convertToInvarianceLabelFormat(testHuePairs(j, :) + lumOffset);
	if ~isequal(trainTrigs, testTrigs)
		if p.powerAnalysis == 1
			runDecodingForPowerAnalysis(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
        elseif nullOpt == 1
			runSignificanceTests(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		else
			runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
		end

	end
else
	% Decode lum within each hue pair
	for i = 1 : size(trainHues, 2)
		for j = 1 : size(testHues, 2)
			disp(['Decoding...Training Hue Pair #' num2str(i) ', Testing Hue Pair #' num2str(j)])
			fileId = ['GenLumAcrossHuesTrainAz' trainHues{i} 'TestAz' testHues{j} '_' attentionCond timewindowStr];
			trainTrigs = convertToInvarianceLabelFormat(trainHuePairs(i, :) + lumOffset)
			testTrigs  = convertToInvarianceLabelFormat(testHuePairs(j, :) + lumOffset)
			if ~isequal(trainTrigs, testTrigs)
				if p.powerAnalysis == 1
					runDecodingForPowerAnalysis(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
                elseif nullOpt == 1
					runSignificanceTests(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
				else
					runDecoding(subjId, fileId, f, p, the_labels_to_use, trainTrigs, testTrigs)
				end
				
			end
		end
	end
end
end
