function runDecoding_ForcedError(subjId, fileId, f, p, the_labels_to_use, train_inds, test_inds)

% Author: Leyla Isik, Poggio Lab with modifications by Katherine Hermann
%   April 2016 version

toolbox_path = f.toolboxPath;
raster_path  = f.rasterPath;
bin_path     = f.binPath;

raster_path

if exist(f.resultsPath,'dir') ~= 7
    mkdir(f.resultsPath)
end

results_path = [f.resultsPath fileId '/']
results_fileName = [subjId '_' fileId '_' num2str(p.nFeat) 'sensors_' num2str(p.nAvg) 'avg_' num2str(p.num_cv_splits) 'splits_' num2str(p.reps_per_split) 'repsPerSplit' f.resultsSuffix '.mat'];


if raster_path(end)~='/'
    raster_path = [raster_path '/'];
end
if bin_path(end)~='/'
    bin_path = [bin_path '/'];
end
if results_path(end)~='/'
    results_path = [results_path '/'];
end

%% add paths
addpath(genpath(toolbox_path));

%% Bin data
if exist(bin_path, 'dir') ~= 7
	mkdir(bin_path)
end

bin_folder = [bin_path fileId '/'];
if exist(bin_folder, 'dir') ~=7
    mkdir(bin_folder)
end

bin_file_name = [bin_path subjID '_' num2str(p.bin_width) ...
    'ms_bins_' num2str(p.step_size) 'ms_sampled.mat'];

if exist(bin_file_name, 'file')~=2
    create_binned_data_from_raster_data([raster_path], [bin_path subjId], p.bin_width, p.step_size);
end
load(bin_file_name);

%% Results path
results_folder = results_path; % TEMP
if exist(results_folder, 'dir')~=7
    eval(['mkdir ' results_folder])
end

%% create a feature preprocessor that z-score normalizes each neuron
% note that the FP objects are stored in a cell array since multiple FP
% which allows mutliple FP objects to be used in one analysis
the_feature_preprocessors{1} = zscore_normalize_FP;
% select significant p-values in preprocessing
the_feature_preprocessors{2}=select_or_exclude_top_k_features_FP;
the_feature_preprocessors{2}.num_features_to_use = p.nFeat;
% save feature preprocessor info
the_feature_preprocessors{2}.save_extra_info = 1; % EDIT HERE to save sensors
if isequal(train_inds,test_inds) % without generalization
   disp('running without generalization')
   ds = avg_DS(bin_file_name, the_labels_to_use, p.num_cv_splits, p.nAvg);  
ds.label_names_to_use = train_inds;
else % with generalization
   disp('running with generalization')
   ds = avg_generalization_DS(bin_file_name, the_labels_to_use,...
        p.num_cv_splits, train_inds, ...
        test_inds, p.nAvg);
end

disp('before DS')
%% DS properties to include for each pe of DS
ds.create_simultaneously_recorded_populations = 1;
ds.num_times_to_repeat_each_label_per_cv_split = p.reps_per_split;
disp('before classifier')
%% create classifier
if strcmp(p.classifierType, 'maxCorr')
    the_classifier = max_correlation_coefficient_CL_ForcedError;
elseif strcmp(p.classifierType, 'svm')
    the_classifier = libsvm_CL_ForcedError;
elseif strcmp(p.classifierType, 'naiveBayes')
    the_classifier = poisson_naive_bayes_CL;
end   
disp('before CV object')
%% create the CV object
the_cross_validator = standard_resample_CV(ds, the_classifier, the_feature_preprocessors);

% set how many times the outer 'bootstrap' loop is run
the_cross_validator.num_resample_runs = p.decoding_runs;
if p.temporal_cross_training == 1
    the_cross_validator.test_only_at_training_times = 0;
    the_cross_validator.confusion_matrix_params.save_confusion_matrix_only_train_and_test_at_same_time = 0;
else
    the_cross_validator.test_only_at_training_times = 1; % use 1; could also do temporal cross-training
    the_cross_validator.confusion_matrix_params.save_confusion_matrix_only_train_and_test_at_same_time = 1;
end
disp('before decoding')
%% run the decoding analysis
DECODING_RESULTS = the_cross_validator.run_cv_decoding;
disp('after decoding')
%% Save data
% save the datasource parameters for our records
DATASOURCE_PARAMS = ds.get_DS_properties;

%save_file_name = [results_folder '/' results_fileName];
save_file_name = [results_folder results_fileName];
disp(save_file_name)
if ~exist(results_folder)
    disp('making directory')
    mkdir(results_folder)
else
    disp('no need to make directory')
end
save([save_file_name '.mat'], 'DECODING_RESULTS', 'DATASOURCE_PARAMS', '-mat');
