
function create_raster_data(subj_path, channel_list, trigger_list, hueLum_labels, hueOnly_labels, lumOnly_labels, timepoints, raster_save_path)

% Author: Katherine Hermann, April 2015
% Updated August 2015 for this pilot; added more label types

% Each folder contains a matrix called "F", which is numChannels x
% numTimepoints long

% INPUTS: subj_path    (folder containing trigger folders)
%         channel_num  (channel number to pull)
%         trigger_list (numbers corresponding to folders of trials)
%         category_labels (labels for categories)
%         timepoints   (vector of timepoint inds to use)
%         raster_save_path (location to save the .mat file)

trigger_labels  = [];
indTrial_labels = [];
hueLum = {};
hue = {};
lum = {};

offset = 0;
for i = 1 : numel(trigger_list)
    i
    trig_folder = strcat(subj_path, num2str(trigger_list(i)), '/');
    %%%filtered_contents = dir(strcat(trig_folder, '*trial*.mat')); % for running with no bandpass
    filtered_contents = dir(strcat(trig_folder, '*bandpass.mat'));
    
    % gather all trials for a given trigger
    for j = 1 : numel(filtered_contents)
        trial = strcat(trig_folder, filtered_contents(j).name);
        load(trial);
        
        m(:, j + offset, :) = F(channel_list, timepoints); % channels x trials --> channels x trials x timepoints matrix

        indTrial_labels{end + 1} = filtered_contents(j).name;
        trigger_labels  = [trigger_labels, trigger_list(i)];
        hueLum{end + 1} = hueLum_labels{i};
        hue{end + 1}    = hueOnly_labels{i};
        lum{end + 1}    = lumOnly_labels{i};
    end
    offset = offset + numel(filtered_contents); % next we'll be adding the next condition to the same raster
    
end

% common labels
raster_labels.hueLum_labels = hueLum;
raster_labels.hue_labels = hue;
raster_labels.lum_labels = lum;
raster_labels.trigger_labels  = trigger_labels;
raster_labels.indTrial_labels = indTrial_labels;

% save as individual .mat's
for i = 1 :  numel(channel_list)
    channel_num = channel_list(i);
    raster_data = squeeze(m(i, :, :));
    raster_site_info = struct('recording_channel', channel_num);
    save(strcat(raster_save_path, 'raster_ch', sprintf('%03d', channel_num), '.mat'), 'raster_data', 'raster_labels', 'raster_site_info');
end

end
