
function create_raster_data_specified_trial_num(subj_path, channel_list,...
    trigger_list, num_trials_to_use, hueLum_labels, hueOnly_labels, lumOnly_labels,...
    timepoints, raster_save_path, trials_used_filename)

% Author: Katherine Hermann, April 2015
% Updated August 2015 for this pilot; added more label types
% This version created September 2015 to work for specified trial number

% Each folder contains a matrix called "F", which is numChannels x
% numTimepoints long

% INPUTS: subj_path    (folder containing trigger folders)
%         channel_num  (channel number to pull)
%         trigger_list (numbers corresponding to folders of trials)
%         category_labels (labels for categories)
%         timepoints   (vector of timepoint inds to use)
%         raster_save_path (location to save the .mat file)

trigger_labels  = [];
indTrial_labels = [];
hueLum = {};
hue = {};
lum = {};

offset = 0;
for i = 1 : numel(trigger_list)
    i
    
    trig_folder = strcat(subj_path, num2str(trigger_list(i)), '/');
    filtered_contents = dir(strcat(trig_folder, '*trial*.mat')); % for running with no bandpass
        
    % Randomly select num_trials_to_use trials
    order = randperm(numel(filtered_contents));
    rnd_inds = sort(order(1 : num_trials_to_use));
    trials_to_use = filtered_contents(rnd_inds);
    trial_names_used{i} = trials_to_use;
    
    % gather all trials for a given trigger
    for j = 1 : numel(trials_to_use)
        trial = strcat(trig_folder, trials_to_use(j).name);
    
        load(trial);
        
        m(:, j + offset, :) = F(channel_list, timepoints); % channels x trials --> channels x trials x timepoints matrix

        indTrial_labels{end + 1} = trials_to_use(j).name;
        trigger_labels  = [trigger_labels, trigger_list(i)];
        hueLum{end + 1} = hueLum_labels{i};
        hue{end + 1}    = hueOnly_labels{i};
        lum{end + 1}    = lumOnly_labels{i};
    end
    offset = offset + numel(trials_to_use); % next we'll be adding the next condition to the same raster
    
end

% common labels
raster_labels.hueLum_labels = hueLum;
raster_labels.hue_labels = hue;
raster_labels.lum_labels = lum;
raster_labels.trigger_labels  = trigger_labels;
raster_labels.indTrial_labels = indTrial_labels;

% save as individual .mat's
for i = 1 :  numel(channel_list)
    channel_num = channel_list(i);
    raster_data = squeeze(m(i, :, :));
    raster_site_info = struct('recording_channel', channel_num);
    save(strcat(raster_save_path, 'raster_ch', sprintf('%03d', channel_num), '.mat'), 'raster_data', 'raster_labels', 'raster_site_info');
end

save(trials_used_filename, 'trial_names_used');

end
