
function createRasterData(subjPath, channelList, timepoints, stimTrigs, stimNameLabels, attentionCondLabels, hueLabels, lumLabels, rasterSavePath)

% April 2016

% INPUTS: subjPath            (folder containing data in folder labeled by trigger. Each trigger folder
%                              contains .mat files for the trials, labeled, e.g. data_7_trial003_03.mat,
%                              where 7 is the trigger, the 03 at the end is the third fif file, and this is
%                              trial 003 for that fif. Note that there is no _01 for the first fif)
%         channelList         (list of channels to use, usually 1 : 306)
%         timepoints          (list of timepoints to use, usually 1 : 801)
%         stimTrigs           (list of stimulus triggers; other triggers were
%                               offset markers, dummy markers, subject responses, etc.)
%         stimNameLabels      (exact stimulus name)
%         attentionCondLabels (HueCond or LumCond)
%         hueLabels           (stimulus DKL azumith)
%         lumLabels           (stimulus DKL elevation)
%         rasterSavePath      (path for saving raster-formatted data, required by NDT. 
%                              For this format, each channel gets its own .mat file, 
%                              e.g. raster_ch001.mat. This .mat contains 3 items: 
%                                      > raster_data, a trials x timepoints data matrix
%                                      > raster_labels, a struct with string arrays containing the
%                                        different labeling schemes -- stimNameLabels, attentionCondLabels, etc.
%                                      > raster_site_info -- the recording channel)
%

rStimTrigs     = [];
rStimNames     = {};
rAttentionCond = {};
rHue           = {};
rLum           = {};      
offset = 0;

for i = 1 : numel(stimTrigs)
    trig = stimTrigs(i);
	disp(trig)
    disp(['trigger :' num2str(trig)])
    
    trigFolder = [subjPath num2str(trig) '/']
	load([trigFolder 'brainstormstudy.mat'],'BadTrials')
    filteredContents = dir([trigFolder '*trial*.mat'])
	
    % we don't order by sequence of presentation, as Isik does, but could
    % it it'd be useful to look at progression
    
    % gather all trials for this trigger
	trialIdx = 1;
    for j = 1 : numel(filteredContents)
        trial = [trigFolder filteredContents(j).name];
		isBad = 0;
		for k = 1:numel(BadTrials)
			if strcmp(BadTrials{k},filteredContents(j).name)
				isBad = 1;
				disp(BadTrials{k})
			end
		end
		
		if ~isBad
			load(trial); % F is a trials x timepoints data matrix
			
			m(:, trialIdx + offset, :) = F(channelList, timepoints); % channels x trials x timepoints matrix
			
			% labels corresponding to this trigger
			rStimTrigs              = [rStimTrigs, trig];
			rStimNames{end + 1}     = stimNameLabels{i};
			rAttentionCond{end + 1} = attentionCondLabels{i};
			rHue{end + 1}           = hueLabels{i};
			rLum{end + 1}           = lumLabels{i};
			trialIdx = trialIdx + 1;
		end
    end
    offset = offset + numel(filteredContents);
end

% common labels
raster_labels.triggers      = rStimTrigs;
raster_labels.stimNames     = rStimNames;
raster_labels.attentionCond = rAttentionCond;
raster_labels.hue           = rHue;
raster_labels.lum           = rLum;

% save as individual .mat files
for i = 1 : numel(channelList)
    channel_num = channelList(i);
    raster_data = squeeze(m(i, :, :));
    raster_site_info = struct('recording_channel', channel_num);
    save([rasterSavePath 'raster_ch' sprintf('%03d', channel_num) '.mat'], 'raster_data', 'raster_labels', 'raster_site_info');
end

end
    
    