
function createRasterData_ROI(subjPath, timepoints, stimTrigs, stimNameLabels, attentionCondLabels, hueLabels, lumLabels, rasterSavePath)

% April 2016

% INPUTS: subjPath            (folder containing data in folder labeled by trigger. Each trigger folder
%                              contains .mat files for the trials, labeled, e.g. data_7_trial003_03.mat,
%                              where 7 is the trigger, the 03 at the end is the third fif file, and this is
%                              trial 003 for that fif. Note that there is no _01 for the first fif)
%         timepoints          (list of timepoints to use, usually 1 : 801)
%         stimTrigs           (list of stimulus triggers; other triggers were
%                               offset markers, dummy markers, subject responses, etc.)
%         stimNameLabels      (exact stimulus name)
%         attentionCondLabels (HueCond or LumCond)
%         hueLabels           (stimulus DKL azumith)
%         lumLabels           (stimulus DKL elevation)
%         rasterSavePath      (path for saving raster-formatted data, required by NDT. 
%                              For this format, each channel gets its own .mat file, 
%                              e.g. raster_ch001.mat. This .mat contains 3 items: 
%                                      > raster_data, a trials x timepoints data matrix
%                                      > raster_labels, a struct with string arrays containing the
%                                        different labeling schemes -- stimNameLabels, attentionCondLabels, etc.
%                                      > raster_site_info -- the recording channel)
%

rStimTrigs     = [];
rStimNames     = {};
rAttentionCond = {};
rHue           = {};
rLum           = {};      
offset = 0;
%preallocate m
for knd = 1:numel(stimTrigs)
    trig = stimTrigs(knd);
    disp(['trigger :' num2str(trig)])

    trigFolder = [subjPath num2str(trig) '/']
    filteredContents = dir([trigFolder '*trial*.mat']);
    if knd ==1
        trial = [trigFolder filteredContents(1).name];
        load(trial,'F'); % F is a trials x timepoints data matrix
    end
     offset = offset + numel(filteredContents);
end
totaltrials = offset
disp(size(F));
disp(totaltrials);
m = zeros(size(F,1),totaltrials,801);
offset = 0;
for i = 1 : numel(stimTrigs)
    tic
    trig = stimTrigs(i);
    disp(['trigger :' num2str(trig)])
    
    trigFolder = [subjPath num2str(trig) '/']
    filteredContents = dir([trigFolder '*trial*.mat']);
    
    % we don't order by sequence of presentation, as Isik does, but could
    % it it'd be useful to look at progression
    % gather all trials for this trigger
    for j = 1 : numel(filteredContents)
        if mod(j,30) == 0; disp(['gathering trial ' num2str(j)]); end
        
        trial = [trigFolder filteredContents(j).name];
        load(trial); % F is a trials x timepoints data matrix

        m(:, j + offset, :) = F(:, timepoints); % channels x trials x timepoints matrix

        % labels corresponding to this trigger            
        rStimTrigs              = [rStimTrigs, trig];
        rStimNames{end + 1}     = stimNameLabels{i};
        rAttentionCond{end + 1} = attentionCondLabels{i};
        rHue{end + 1}           = hueLabels{i};
        rLum{end + 1}           = lumLabels{i};
    end
    offset = offset + numel(filteredContents);
    toc
end
% common labels
raster_labels.triggers      = rStimTrigs;
raster_labels.stimNames     = rStimNames;
raster_labels.attentionCond = rAttentionCond;
raster_labels.hue           = rHue;
raster_labels.lum           = rLum;

% save as individual .mat files, one for each source
for i = 1 : size(m, 1)
    source_num = i;
    raster_data = squeeze(m(i, :, :));
    raster_site_info = struct('source_', source_num);
	save([rasterSavePath 'raster_ch' sprintf('%03d', source_num) '.mat', '-binary'], 		'raster_data', 'raster_labels', 'raster_site_info');
end

end
    
    
