% sensors2vertices
% Convert [sensors]x[timepoints] to [anatomical vertices]x[timepoints]
% 3/6/2017 Dimitrios Pantazis, Santani Teng
% v2 3/16/17 tweaks parameters, condition naming, anatomy flag, savefile
% naming, some output during processing
%edited 6/6/17 Isabelle Rosenthal
function [] = sensors2vertices_forDecodingm(Subjects, paths, ncond, Subjects_customanatflag, Atlas_Name, ROIs_toUse, roisName)

%Subjects_customanatflag = [1 1 1 0 1 1 1 0 0 1 1 0]; %custom (MRI) anatomy? 1=yes, 0=no

% Initialize parameters
addpath(genpath(paths.toolboxPath));
brainstormdbpath    = paths.brainstormdbpath;
proj                = paths.proj;                  
savepath            = paths.savepath; 

disp(ncond)
%excludeVector       = [4 8];                    %conditions to exclude; [] for none
excludeVector       = []; 
condPrefix          = [];                       %condition naming string (e.g. 'braille')
condition           = sprintfc([condPrefix '%g'],ncond);   %condition = cellfun(@num2str,num2cell(1:N),'uni',false);
Time                = [-200:600];

channelname         = {'MEG'};
%lowpassfreq         = 30; %USE THIS? going to say no. input for load
%brainstorm trials
disp([num2str(length(Subjects_customanatflag)) ' custom anatomys flags for ' num2str(length(Subjects)) ' subjects']);

%which rois to decode
roindx = ROIs_toUse;
nrois = size(roindx,1);

for i = 1:length(Subjects)
    subjsSessions = {[Subjects{i} '_sess01'],[Subjects{i} '_sess02']};
    subjSavePath = [savepath Subjects{i} '/'];
    if ~exist(subjSavePath)
        mkdir(subjSavePath)
    end
    % Load trials
    for c = 1:numel(ncond)
        disp(['loading subject ' Subjects{i} ' condition ' num2str(ncond(c)) ' trials']);
        [sess01Trial,Time, sess01Name] = load_brainstorm_trials(brainstormdbpath,proj,subjsSessions{1},condition{c},channelname);
        [sess02Trial,Time, sess02Name] = load_brainstorm_trials(brainstormdbpath,proj,subjsSessions{2},condition{c},channelname);
        trial{c} = [sess01Trial sess02Trial];
        %rename trials for sess02 so don't overwrite
        trialName{c} = [sess01Name regexprep(sess02Name, '.mat','_s02.mat')];
    end
    
    % Transform trials into ROI time courses. (S=imagingkernel*trial; S=15002xTime;
    
    % Load imaging kernel, D-K
    imgkernelpath       = [brainstormdbpath filesep proj filesep 'data' filesep subjsSessions{1} filesep '@default_study'];
    imgkernelfile       = dir(fullfile(imgkernelpath,'*results*'));
    imgkernelfile       = fullfile(imgkernelpath,imgkernelfile.name);
    ImagingKernel       = load(imgkernelfile);
    ImagingKernel       = ImagingKernel.ImagingKernel;
    
    %load cortex file to get atlas
    if Subjects_customanatflag(i)
        cortexfile = fullfile(brainstormdbpath,proj,'anat',subjsSessions{1},'tess_cortex_pial_low.mat');
    else
        cortexfile = fullfile(brainstormdbpath,proj,'anat','@default_subject','tess_cortex_pial_low.mat');
    end
    cortex = load(cortexfile);
    
    %edit for atlas
    atlasndx = strfind({cortex.Atlas.Name},Atlas_Name);
    atlasndx = find(~cellfun(@isempty,atlasndx));
    Scouts = cortex.Atlas(atlasndx).Scouts;
    
    for roi = 1:nrois
        saveRoiName = roisName{roi};
        saveRoiName = saveRoiName(1:end-2)
        roiSavePath = [subjSavePath saveRoiName '/'];
        if ~exist(roiSavePath)
            mkdir(roiSavePath)
        end
        clear vertices
        vertices = [];
        editVerticesFlag = 0;
        for subRoi = 1:size(ROIs_toUse,2) %for each ROI within the ROI to combine
            disp([Subjects{i} ' ROI #' num2str(roindx(roi,subRoi)) ', ' roisName{roi}]);

            %combine the vertices of the Rois together, get inverse for roi
            if editVerticesFlag == 0 && max(size(Scouts(roindx(roi, subRoi)).Vertices)) == size(Scouts(roindx(roi, subRoi)).Vertices,1) %if the vertices are the wrong dimension for some reason
                editVerticesFlag = 1;
                vertices = [vertices' Scouts(roindx(roi, subRoi)).Vertices'];
            elseif editVerticesFlag == 1;
                vertices = [vertices Scouts(roindx(roi, subRoi)).Vertices'];
            else
                vertices = [vertices Scouts(roindx(roi, subRoi)).Vertices];
            end
        end %subROI loop
        
        ImagingKernel_roi = ImagingKernel(vertices,:);
        
        %convert trials to source time series
        for c = 1:numel(ncond)
            condSavePath = [roiSavePath condition{c} '/'];
            if ~exist(condSavePath)
                mkdir(condSavePath)
            end
            for tr = 1:length(trial{c})
                %Roi_cell{c}{tr} = ImagingKernel_roi*trial{c}{tr};
                F =  ImagingKernel_roi*trial{c}{tr};
                %save all in outer folder labeled by what ROI it is
                %     have folder with name of condition (1:10)
                %in this, .mat files for each trial named appropriately
                %looks for sources x timepoints data matrix
                if tr == 1
                    roiCreationInfo.numSources = size(F,1); %same on all trials
                end
                save([condSavePath trialName{c}{tr}],'F')
                clear F
                
            end%trial loop
            roiCreationInfo.roi = roisName{roi} ;
            roiCreationInfo.condition = condition(c);
            roiCreationInfo.subj = Subjects{i};
            save([condSavePath 'roiInfo.mat'], 'roiCreationInfo')
        end %condition loop
    end  %roi loop
end %subject loop
end

%for each condition: have folder with name of condition (1:10)
%in this, .mat files for each trial named appropriately

%want a folder containing data labeled by trigger, each folder has .mat
%files for the trials, labeled e.g. data_7_train003_03.mat
%  where 7 is the trigger, the 03 at the end is the third fif file, and this is
% trial 003 for that fif. Note that there is no _01 for the first fif)
%also a general file with 
% --number of sources

%on each raster_data 5012x801
%raster_labels with triggers
%raster_site_info
%so basically the entire set of trials that have not been sorted by label

%binned data
%original has:
%binned_data 1x306 cell array. In each slot is 5012x160 matrix
%binned_labels 1x1 struct containing triggers 1x306 cell with each slot is
%1x4971 with 1:10 numbers in order?
%binned_site_info 1x1 struct containing:
% --recording channel 306x1 matrix that's just 1:306
% --binning parameters


% AccuracyCC_exc(:,:,excludeVector,:,:,:)=[];
% AccuracyCC_exc(:,:,:,excludeVector,:,:)=[];

%accuracyfile = [proj '_ROIAcc_' num2str(length(Subjects)) 'Ss_' num2str(length(roindx)) 'ROIs.mat'];
%save([savepath filesep accuracyfile],'Accuracy','AccuracyCC_exc','roindx','roindx_names','Subjects','Time');



