
function splitExperimentsAndConvertToRaster(subj_ID, eyeTrack, timepoints)

% Author:  Katherine Hermann
% History: Created August 2015 for HG Pilot; based on April scripts
%          Updated March 2016

% NOTE: 1. Always look at your raw data. There's a way to remove bad channels
%          (check with Dimitrios)

% INPUTS: subjPath         (path to brainstorm_db/subj/data/subj files containing
%                            DC-offset-removed data, optionally bandpass filtered)
%         eyeTrack: 0 to not use eye data, 1 for using eye position, 2 for using pupil diameter 
%         

switch eyeTrack
	case 0
		useEyetrackingChannels = 0;
	case 1
		useEyetrackingChannels = 1;
		eyetrackingDesc = 'EyePosition';
	case 2
		useEyetrackingChannels = 1;
		eyetrackingDesc = 'PupilDiameter';
end

if nargin < 3
	timepoints  = [1 : 801]; % used -200 : 600 during preprocessing
end

%% File handling
% UPDATE AS APPROPRIATE:
if timepoints(end) == 1401
	suffix = '_LongWindow';
else
	suffix = '';
end
protocolPath   = [pwd '/../../Intermediates_Data' suffix '/data/'];

rasterRoot = [pwd '/../../Intermediates_Study/'];

if useEyetrackingChannels == 1
    rasterRoot = [rasterRoot 'EyePositionDecoding/' eyetrackingDesc '/'];
end
rasterPath = [rasterRoot 'Raster_Format' suffix '/'];
rasterSavePath = [rasterPath subj_ID '/'];
subjPath       = [protocolPath subj_ID '/']; 

disp(['Subject data path: ' subjPath])
disp(['Raster path: ' rasterPath])

%% Set params
if useEyetrackingChannels == 1
    if strcmp(eyetrackingDesc, 'PupilDiameter')
        % 307-312 correspond to the eyetracker channels
        channelList = [309, 312]; 
        %channelList = [309];
    elseif strcmp(eyetrackingDesc, 'EyePosition')
        channelList = [307, 308, 310, 311]; % 307-308 are right eye position (I *think*), 310-311 are left eye position
        %channelList = [307, 308]; % subj with right-eye tracking only
    end
else
    channelList = [1 : 306]; % MEG channels to use (use [1 : 306] unless there's reason to think one was awry after reviewing the raw data)
end


%% Create rasters
% specify stimuli
stimNames = {'az45sat75elev20','az45sat75elev340','az135sat75elev20',...
             'az135sat75elev340','az225sat75elev20','az225sat75elev340',...
             'az315sat75elev20','az315sat75elev340', 'green', 'blue'};
% stimulus trigger codes
stimTrigs = [1 : 10, 51 : 60];  
% create a couple sets of labels:
%   stimNameLabels      (exact stimulus name)
%   attentionCondLabels (HueCond or LumCond)
%   hueLabels           (stimulus DKL azumith)
%   lumLabels           (stimulus DKL elevation)
stimNameLabels = [stimNames stimNames];
for i = 1 : 10
    attentionCondLabels{i} = 'Hue';
end
for i = 11 : 20
    attentionCondLabels{i} = 'Lum';
end
hues = {'45', '45', '135', '135', '225', '225', '315', '315', 'NA', 'NA'};
lums = {'20', '340', '20', '340', '20', '340', '20', '340', 'NA', 'NA'};
hueLabels = [hues, hues];
lumLabels = [lums, lums];

if ~exist(rasterSavePath)
    mkdir(rasterSavePath)
else
    disp('This raster path already exists. To proceed, press enter')
    pause
end

createRasterData(subjPath, channelList, timepoints, stimTrigs, stimNameLabels, attentionCondLabels, hueLabels, lumLabels, rasterSavePath);
% NOTE that you will want to modify this procedure so that the same numbers
% of trials are being used if comparing results of different decoding problem

end
