% converts the trial data to a raster format
% 
% subj is an optional parameter (in the form 'lilac[xx]') for rasterizing 
% just one subject, or can pass no parameters, in which case all subjects 
% are rasterized one by one.
% 
% Timepoints is optional and can be [1:801] for the [-200,600] ms time 
% window or [1:1401] for the [-200,1200] ms time window. Default is [1:801]
%
% eyeTrack is an optional parameter used for rasterizing eye tracking data. 
% Default is 0, which means the MEG data is rasterized. To rasterize eye
% position data, pass 1, and to rasterize pupil diameter data, pass 2
function wrapper_prepAllSubjects(subj, timepoints, eyeTrack)

if nargin < 1

	subjectIds = {'lilac04_sess01', 'lilac04_sess02'...
				  'lilac05_sess01', 'lilac05_sess02'...
				  'lilac06_sess01', 'lilac06_sess02'...
				  'lilac07_sess01', 'lilac07_sess02'...
				  'lilac10_sess01', 'lilac10_sess02'...
				  'lilac12_sess01', 'lilac12_sess02'...
				  'lilac13_sess01', 'lilac13_sess02'...
				 'lilac14_sess01', 'lilac14_sess02'...
				 'lilac15_sess01', 'lilac15_sess02'...
				  'lilac16_sess01', 'lilac16_sess02'...
				 'lilac17_sess01', 'lilac17_sess02'...
				 'lilac18_sess01', 'lilac18_sess02'...
				 'lilac19_sess01', 'lilac19_sess02'...
				 'lilac20_sess01', 'lilac20_sess02'...
				  'lilac21_sess01', 'lilac21_sess02'...
				 'lilac22_sess01', 'lilac22_sess02'...
				 'lilac23_sess01', 'lilac23_sess02'...
				  'lilac24_sess01', 'lilac24_sess02'};

	wholeSubjs = {'lilac04',...
				  'lilac05',...
				  'lilac06',...
				  'lilac07',...
				  'lilac10',...
				  'lilac12',...
				  'lilac13',...
				  'lilac14',...
				  'lilac15',...
				  'lilac16',...
				  'lilac17',...
				  'lilac18',...
				  'lilac19',...
				  'lilac20',...
				  'lilac21',...
				  'lilac22',...
				  'lilac23',...
				  'lilac24'};

else
	sess1Str = [subj '_sess01'];
	sess2Str = [subj '_sess02'];
	subjectIds = {sess1Str,sess2Str};
	wholeSubjs = {subj};
end

if nargin < 2
	timepoints = 1:801;
end

if nargin < 3
    eyeTrack = 0;
end

disp(subjectIds)
disp(wholeSubjs)

for s = 1 : numel(subjectIds)
    disp(['Beginning subject ' num2str(s) '/' num2str(numel(subjectIds))]);
    splitExperimentsAndConvertToRaster(subjectIds{s}, eyeTrack, timepoints);
end

if timepoints(end) == 1401
	rasterSuffix = '_LongWindow'
else
	rasterSuffix = ''
end
for s = 1:numel(wholeSubjs)
 disp(['COMBINING: subject ' num2str(s) '/' num2str(numel(wholeSubjs))]);
 combineRastersFromMultipleSessions(wholeSubjs{s}, eyeTrack,rasterSuffix);
end

end
