
function p = initializeDecodingParameters(classifierType, eyePositionOpt)

%% Parameters
% NOTE: At the very beginning of the decoding procedure, we average data in
% p.bin_width-ms bins to reduce noise. The decoding toolbox uses k-fold 
% cross-validation, meaning that it splits the data into k sections, 
% leaves one of these out as a test set, and trains on the remainder. 
% We control the number of cv splits with the parameter p.num_cv_splits.
% Each cv split contains reps_per_split-many repetitions of each label. 
% As an example, if we set reps_per_split = 10, each of our num_cv_split 
% sections will contain 10 examples of each class. MEG data is noisy; 
% the decoding toolbox allows us to average sets of trials together to 
% form training templates. A training template is the averaged set of 
% nAvg class examples. If we decide to do 6 cv splits, and use 10 reps 
% per split, averaged in sets of 10 (p.nAvg = 10), this means we will 
% only have one training template per cv split. This is a bit confusing, 
% as num cv splits could also have meant the target number of training 
% templates (averaged sets) to use. If we want to include more than one 
% training template per split, we must select nAvg that divides evenly 
% into num reps per split. For example, we could include 80 reps per split, 
% averaged into sets of 40, which would mean we're using 2 templates per 
% split during decoding.

if eyePositionOpt == 1 % decode from eye position, not MEG data
    p.classifierType  = classifierType;
	p.eyetrackingDesc = 'PupilDiameter'; % 'PupilDiameter' or 'EyePosition'
    p.decoding_runs    = 50; %50
    p.nFeat            = 2; %2 for pupil diameter, 4 for eye position (right and left x and y) -- update other parts of code as appropriate
    p.bin_width        = 5;  %5
    p.step_size        = p.bin_width; %5 if same as bin width, then steps are non-overlapping
    p.num_cv_splits    = 5;
    p.reps_per_split   = 75;
    p.nAvg             = 75;
else
    p.classifierType  = classifierType;
    p.decoding_runs    = 50; 
    p.nFeat            = 25; %(sensors used during sensor selection)
    p.bin_width        = 5;  %5 or 50 for temp X decoding
    p.step_size        = p.bin_width; %5 if same as bin width, then steps are non-overlapping
    
    % NOTE: p.num_cv_splits * p.reps_per_split must not exceed the number of trials available
    p.num_cv_splits    = 5; 
    p.reps_per_split   = 75; 
    p.nAvg             = 75; 
end

% generate matrix for temporal cross-validation
p.temporal_cross_training = 0; %1 to temporal cross-train, 0 to not
p.powerAnalysis = 0; %set to 1 to do poweranalysis
p.powerRuns = 1:10; %runs numbers for power analysis output file suffixes
p.longWindow = 0; %set to 1 to use 1200 ms window

p.nullIterRange = 1:200; % number of null decoding runs to do if nullOpt=1

end
