
function p = initializeDecodingParameters_ROI(classifierType)

%% Parameters
% NOTE: At the very beginning of the decoding procedure, we average data in
% p.bin_width-ms bins to reduce noise. The decoding toolbox uses k-fold 
% cross-validation, meaning that it splits the data into k sections, 
% leaves one of these out as a test set, and trains on the remainder. 
% We control the number of cv splits with the parameter p.num_cv_splits.
% Each cv split contains reps_per_split-many repetitions of each label. 
% As an example, if we set reps_per_split = 10, each of our num_cv_split 
% sections will contain 10 examples of each class. MEG data is noisy; 
% the decoding toolbox allows us to average sets of trials together to 
% form training templates. A training template is the averaged set of 
% nAvg class examples. If we decide to do 6 cv splits, and use 10 reps 
% per split, averaged in sets of 10 (p.nAvg = 10), this means we will 
% only have one training template per cv split. This is a bit confusing, 
% as num cv splits could also have meant the target number of training 
% templates (averaged sets) to use. If we want to include more than one 
% training template per split, we must select nAvg that divides evenly 
% into num reps per split. For example, we could include 80 reps per split, 
% averaged into sets of 40, which would mean we're using 2 templates per 
% split during decoding.

p.classifierType  = classifierType;
p.decoding_runs    = 50; %50
p.nFeat            = 25; %25 number of features (sensors used during sensor selection)
p.bin_width        = 5;  %5 or 50 for temp X decoding
p.step_size        = p.bin_width; %5 if same as bin width, then steps are non-overlapping

% NOTE: p.num_cv_splits * p.reps_per_split must equal the number of trials available
p.num_cv_splits    = 5; %6;%5;  % for single sess use 4 //6 in Spirals Pilot, where we had max 499 trials available
p.reps_per_split   = 75; %80;%75; % for single sess use 25 //80 in Spirals Pilot
p.nAvg             = 75; %80; %75; % for single sess use 25 //10 in Spirals pilot

p.temporal_cross_training = 0; %1 to temporal cross-train, 0 to not
p.powerAnalysis = 0; %set to 1 to do poweranalysis
p.powerRuns = 1:10; %runs numbers for power analysis output file suffixes
p.longWindow = 0; %set to 1 to use 1200 ms window

p.plot_flag        = 1;
p.random_shuffle_option = 0; % always start as 0

% number of null pts in perm test
p.nullIterRange = 1:200; % number of null decoding runs to do if nullOpt=1
p.temporal_cross_training = 0; %1 to temporal cross-train, 0 to not

end
