% Plots the decoding accuracy for the spiral identity problem 
% Produces Figs 2a, 2b
% 9-15-2020 Shridhar Singh

clearvars
close all

initializePaths

%% load MEG decoding results
problem = 'SpiralIdentity';
filename = [problem '_decoding_results.mat'];
if ~exist([quantitativeDataDir filename],'file')
    outStruct = gather_spiralID_results();
else
    load([quantitativeDataDir filename]);
end
megResults = outStruct;

%load results of decoding from eye data
eyeTrackDesc = {'EyePosition','PupilDiameter'};
sensorNums = [4,2];
for i = 1:numel(eyeTrackDesc)
    eyeTrack = eyeTrackDesc{i};
    sensorNum = sensorNums(i);
    eye_params_desc = [num2str(sensorNum) 'sensors_75avg_5splits_75repsPerSplit'];
    resultsPath = [studyPath 'Geometry_noBadTrials/Quantitative_Data/' eyeTrack '/' eye_params_desc '/']; 
    if ~exist([resultsPath eyeTrack '_decoding_results.mat'],'file')
        gather_eyeDecoding_results()
    end
    load([resultsPath eyeTrack '_decoding_results.mat']);
    eyeResults.(eyeTrack) = outStruct;
end

%% plot decoding for all individual colors
colorMat = [0.9803921568627451, 0.7843137254901961, 0.9490196078431372;... % az45 elev20
    0.8666666666666667, 0.6078431372549019, 0.8274509803921568;... %    elev340
    0.7333333333333333, 0.8352941176470589, 0.9490196078431372;... %az135
    0.5294117647058824, 0.6823529411764706, 0.8313725490196079;...
    0.6313725490196078, 0.8784313725490196, 0.6862745098039216;... %az225
    0.3137254901960784, 0.7372549019607844, 0.44313725490196076;...
    0.9176470588235294, 0.8274509803921568, 0.6823529411764706;... %az315
    0.792156862745098, 0.6705882352941176, 0.4392156862745098];

bin_width = 5;
firstTime = -200;
lastTime = 595;
num_bins = (lastTime-firstTime+bin_width)/bin_width;
bin_starts = linspace(firstTime,lastTime,num_bins);
y_range = [0, .8];
chance = 0.125;

colorOrder = [3,4,5,6,7,8,2,1];
figure(1)
for i = colorOrder
    plot(bin_starts,megResults.bootByColorDetails(i).mean+chance,'Color',colorMat(i,:),'LineWidth',3);
    hold on
    for t = 1 : numel(megResults.bootByColorDetails(i).tndx_onsetOnwards)
        tI = megResults.bootByColorDetails(i).tndx_onsetOnwards(t)-1;
        full_bin = bin_starts(tI) : bin_starts(tI) + bin_width;
        line(full_bin,ones(size(full_bin))*(y_range(1) + 0.01*i),'linewidth',2,'Color',colorMat(i,:));
    end
end

xlim([-200, 600])
ylim(y_range)
line(bin_starts, chance * ones(1, numel(bin_starts)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);

% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
set(gca,'fontsize',20);
grid off
box off

xlabel('Time (ms)', 'FontWeight', 'bold', 'FontSize', 18)
ylabel('Classification Accuracy (%)', 'FontWeight', 'bold', 'FontSize', 18)
title('Spiral Identity', 'FontSize', 18)

%print('-f1',[figuresDir,'Fig2B'],'-dpng','-r300')

%% plot decoding results averaged across all colors
mean_acc = mean(megResults.allIndivCurves);

meanAccBoot = sort(megResults.bootDetails.timecourse.boot,2)+chance;
meanAccCI = [meanAccBoot(:,25), meanAccBoot(:,975)]';

CIDists = abs(mean_acc - meanAccCI)';
    
for i = 1:numel(eyeTrackDesc)
    eyeTrack = eyeTrackDesc{i};
    eyeResults.(eyeTrack).mean_acc = mean(eyeResults.(eyeTrack).allIndivCurves);
    eyeResults.(eyeTrack).meanAccBoot = sort(eyeResults.(eyeTrack).bootDetails.timecourse.boot,2)+chance;
    eyeResults.(eyeTrack).meanAccCI = [eyeResults.(eyeTrack).meanAccBoot(:,25),...
        eyeResults.(eyeTrack).meanAccBoot(:,975)]';
    eyeResults.(eyeTrack).CIDists = abs(mean_acc - meanAccCI)';
end

figure(2)
boundedline(bin_starts,mean_acc,CIDists,'cmap',[0 0 0]);
hold on
for t = 1 : numel(megResults.bootDetails.tndx_onsetOnwards)
    tI = megResults.bootDetails.tndx_onsetOnwards(t)-1;
    full_bin = bin_starts(tI) : bin_starts(tI) + bin_width;
    line(full_bin,ones(size(full_bin))*(y_range(1) + 0.03),'linewidth',2,'Color',[0 0 0]);
end

eyeTrackColors = [213, 113, 13; 1, 1, 155] / 255;
for i = 1:numel(eyeTrackDesc)
    eyeTrack = eyeTrackDesc{i};
    eyeTrackColor = eyeTrackColors(i,:);
    boundedline(bin_starts,eyeResults.(eyeTrack).mean_acc,eyeResults.(eyeTrack).avgSTDError,...
        'cmap',eyeTrackColor,'transparency',1);
    for t = 1 : numel(eyeResults.(eyeTrack).bootDetails.tndx_onsetOnwards)
        tI = eyeResults.(eyeTrack).bootDetails.tndx_onsetOnwards(t)-1;
        full_bin = bin_starts(tI) : bin_starts(tI) + bin_width;
        line(full_bin,ones(size(full_bin))*(y_range(1)+0.01),'linewidth',2,'Color',eyeTrackColor);
    end
end
xlim([-200, 600])
ylim(y_range)
line(bin_starts, chance * ones(1, numel(bin_starts)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
set(gca,'fontsize',20);
grid off
box off

xlabel('Time (ms)', 'FontWeight', 'bold', 'FontSize', 18)
ylabel('Classification Accuracy (%)', 'FontWeight', 'bold', 'FontSize', 18)
title('Spiral Identity', 'FontSize', 18)

sigTimes = bin_starts(megResults.bootDetails.tndx_onsetOnwards);

%print('-f2',[figuresDir,'Fig2B'],'-dpng','-r300')


%% Confidence intervals on time to peak

%define stimulus offset
offsetTime = megResults.offsetTime;
offsetStartI = find(bin_starts==offsetTime);
[offsetPeak,offsetPeakI] = max(mean_acc(offsetStartI:end));
offsetPeakI = offsetPeakI + offsetStartI - 1;
offsetPeakTime = bin_starts(offsetPeakI);

%on first peak (corresponding to stimulus onset)
bootTC = megResults.bootDetails.timecourse.boot;
for i = 1:1000
   [peak1(i),peak1I(i)] = max(bootTC(1:offsetStartI,i));
end

peak1Times = bin_starts(peak1I)
peak1Times = sort(peak1Times);
peak1CI = [peak1Times(25),peak1Times(975)]

%on second peak (corresponding to stimulus offset)
bootTC = megResults.bootDetails.timecourse.boot;
for i = 1:1000
   [peak2(i),peak2I(i)] = max(bootTC(offsetStartI:end,i));
   peak2I(i) = peak2I(i) + offsetStartI -1;
end

peak2Times = bin_starts(peak2I);
peak2Times = sort(peak2Times);
peak2CI = [peak2Times(25),peak2Times(975)]
