% polar plot of the peak decoding accuracy for each color. 

clearvars
close all

%% load data

initializePaths

problem = 'SpiralIdentity';
filename = [problem '_peak_adjusted_decoding_results.mat'];
filepath = [quantitativeDataDir filename];

if ~exist(filepath,'file')
    adjust_peaks(problem)
end
load(filepath)

theta = ([45 135 225 315]./360)*2*pi;
colorMark = [250 199 241;
    187 213 242
    159 225 174
    233 212 173]./255; %elev20
colorMark(:,:,2) = [221 153 210;
    135 174 211
    77 189 112
    201 172 111]./255; %elev340

%% with standard deviation error bars

numStim = size(meanConMats,1);
elev20ind = [1:2:numStim];
elev340ind = [2:2:numStim];

peakInd = find(relativeTimes==0);
norm_avg_diag = diag(meanConMats(:,:,peakInd));
st_dev_diag = diag(meanConMatStds(:,:,peakInd));


figure1 = figure('Color',[1 1 1])
p1 = polar([theta theta(1)], [norm_avg_diag(elev20ind)' norm_avg_diag(elev20ind(1))'], '-k') 
p1.LineWidth = 2;
hold on
p2 = polar([theta theta(1)], [norm_avg_diag(elev340ind)' norm_avg_diag(elev340ind(1))'], '--k') 
p2.LineWidth = 2;

hold on
polarwitherrorbar(theta, norm_avg_diag(elev20ind)',st_dev_diag(elev20ind)', 'k');
hold on
polarwitherrorbar(theta, norm_avg_diag(elev340ind)',st_dev_diag(elev340ind)','-k');

hold on
for jnd = 1:4
    h(jnd) = polar(theta(jnd), norm_avg_diag(elev20ind(jnd))', 'o'); 
    set(h(jnd), 'markerfacecolor', colorMark(jnd,:,1));
    set(h(jnd), 'markersize', 10);
    set(h(jnd), 'markeredgecolor', [0 0 0]);
    hold on
end
hold on
%plot high lum polar plot
for knd = 1:4
    h(jnd+knd) = polar(theta(knd), norm_avg_diag(elev340ind(knd))', 'o'); 
    set(h(jnd+knd), 'markerfacecolor', colorMark(knd,:,2));
    set(h(jnd+knd), 'markersize', 10);
    set(h(jnd+knd), 'markeredgecolor', [0 0 0]);
    hold on
end
allText = findall(gcf,'Type','text');

for i = 1:length(allText)
    set(allText(i),'FontSize',10)
end
% can choose to have text labels on plot or just the plain polar plot
% delete(allText)pax = gca;
pax.FontSize = 10;
title('Classifier Accuracies in Spiral Identity Decoding Problem by Stimulus') 

%% polar plot with 95% CI error bars

diagConMatBootMean = mean(diagConMatBoot,2);
diagConMatCIDists = abs(diagConMatCI - diagConMatBootMean);
diagConMatBootMean = squeeze(diagConMatBootMean);

peakInd = find(relativeTimes==0);

figure2 = figure('Color',[1 1 1])
%PA = polaraxes;
p1 = polar([theta theta(1)], [diagConMatBootMean(elev20ind,peakInd)' diagConMatBootMean(elev20ind(1),peakInd)'], '-k') 
p1.LineWidth = 2;
hold on
p2 = polar([theta theta(1)], [diagConMatBootMean(elev340ind,peakInd)' diagConMatBootMean(elev340ind(1),peakInd)'], '--k') 
p2.LineWidth = 2;
hold on
polarwitherrorbar(theta, diagConMatBootMean(elev20ind,peakInd)',diagConMatCIDists(elev20ind,peakInd)', 'k');
hold on
polarwitherrorbar(theta, diagConMatBootMean(elev340ind,peakInd)',diagConMatCIDists(elev340ind,peakInd)','-k');

hold on
for jnd = 1:4
    h(jnd) = polar(theta(jnd), diagConMatBootMean(elev20ind(jnd),peakInd)', 'o'); 
    set(h(jnd), 'markerfacecolor', colorMark(jnd,:,1));
    set(h(jnd), 'markersize', 10);
    set(h(jnd), 'markeredgecolor', [0 0 0]);
    hold on
end
hold on
%plot high lum polar plot
for knd = 1:4
    h(jnd+knd) = polar(theta(knd), diagConMatBootMean(elev340ind(knd),peakInd)', 'o'); 
    set(h(jnd+knd), 'markerfacecolor', colorMark(knd,:,2));
    set(h(jnd+knd), 'markersize', 10);
    set(h(jnd+knd), 'markeredgecolor', [0 0 0]);
    hold on
end
allText = findall(gcf,'Type','text');

for i = 1:length(allText)
    set(allText(i),'FontSize',10)
end
% can choose to have text labels on plot or just the plain polar plot
% delete(allText)
pax = gca;
pax.FontSize = 10;
title('Classifier Accuracies in Spiral Identity Decoding Problem by Stimulus') 
