% figure 2E
% make heatmap of forced error choices 
% Isabelle Rosenthal and Shridhar Singh

clearvars
close all

initializePaths;

problem = 'SpiralIdentityForcedError';

classifier = 'MaxCorr';
params_desc = '25sensors_75avg_5splits_75repsPerSplit';

filename = [problem '_peak_adjusted_decoding_results.mat']; 
filepath = [quantitativeDataDir filename];
if ~exist(filepath,'file')
    adjust_peaks('SpiralIdentityForcedError')
end
load(filepath)

nSubjs = size(allConMats,3);
peakInd = find(relativeTimes==0);
allConMats = allConMats(:,:,:,peakInd);
peak_normed_valsBySubj = allConMats;
normalized_avg = squeeze(mean(allConMats,3));
st_dev = std(allConMats,0,3)/sqrt(size(allConMats,3));
chance = 1/size(normalized_avg,1);
    
%bootstrap over the subjects to get confidence intervals to determine which
%vaues are significantly different from chance
nBoots = 1000;
nSubj = size(allConMats,3);
for iBoot = 1:nBoots
    iSubjInds = datasample(1:nSubj, nSubj);
    iNormed = allConMats(:,:,iSubjInds);
    normalized_avg_boot(iBoot,:,:) = mean(iNormed,3);
end
sorted_normBoot = sort(normalized_avg_boot);

%compare the upper and lower bounds to chance to determine which squares in
%the heatmap get an asterisk
boots.lowerNorms = squeeze(sorted_normBoot(25,:,:));
boots.upperNorms = squeeze(sorted_normBoot(975,:,:));


%reorder in terms of concordance (orange,pink,green,blue)
numIms = size(normalized_avg,1);
ranked_xInds = reshape(repmat([7,8,1,2,5,6,3,4],numIms,1), numIms*numIms,1);
ranked_yInds = reshape(repmat([7,8,1,2,5,6,3,4],1,numIms), numIms*numIms,1);

for jnd = 1:(numIms*numIms)
ranked_avg(jnd) = normalized_avg(ranked_xInds(jnd),ranked_yInds(jnd));
boots.lowerNormsRanked(jnd) = boots.lowerNorms(ranked_xInds(jnd),ranked_yInds(jnd));
boots.upperNormsRanked(jnd) = boots.upperNorms(ranked_xInds(jnd),ranked_yInds(jnd));

end
reshaped_ranked_avg = reshape(ranked_avg,8,8);
boots.lowerNormsRanked = reshape(boots.lowerNormsRanked,8,8);
boots.upperNormsRanked = reshape(boots.upperNormsRanked,8,8);

belowChanceI = boots.upperNormsRanked < 1/7;
aboveChanceI = boots.lowerNormsRanked > 1/7;
%%
figure1 = figure('Color',[1 1 1]);
axes1 = axes('Parent',figure1,'Layer','top','YDir','reverse','XTick',[],...
    'YTick',[], 'XLim', [0 size(normalized_avg,1)+1], 'YLim', [0 size(normalized_avg,2)+1]);
box(axes1,'on');
hold(axes1,'on');

imagesc(reshaped_ranked_avg,'Parent',axes1,'CDataMapping','scaled');
xlabel('Actual Class','FontSize',18);
ylabel('Predicted Class','FontSize',18,'Color',[0.15 0.15 0.15]);
colorbar('peer',axes1);
title(['Mean normalized pairwise decoding accuracy (n=' num2str(nSubjs) ')'], 'FontSize', 16)
annotation(figure1,'textbox',...
        [0.61 0 0.181300884955752 0.07],...
        'String',{['sampled at individual peak accuracies']},...
        'FontSize', 12, 'FitBoxToText','on', 'LineStyle','none');
    
bottomColor = [21 67 216]/255; %blue
topColor = [216 50 21]/255; %red

numVals = size(normalized_avg,1);
chanceVal = 1/(numVals-1); %for forced error
cmap = create_chanceAligned_colormap(chanceVal, max(normalized_avg,[],'all'),...
min(normalized_avg,[],'all'), topColor, bottomColor);
colormap(cmap);   

hold on;
    
%add grid on
for row = 0 : 1 : size(normalized_avg,1)
  line([0.5, size(normalized_avg,1) + .5], [row+.5, row+.5], 'Color', 'k');
end
for col = 0 : 1 : size(normalized_avg,1)
  line([col+.5, col+.5], [0.5, size(normalized_avg,1) + .5], 'Color', 'k');
end

L = 0.10;
for row = 1:size(aboveChanceI,1)
    for col = 1:size(aboveChanceI,2)
        if aboveChanceI(row,col) == 1
           line([col-L col+L],[row-L row+L],'Color','k')
           line([col+L col-L],[row-L row+L],'Color','k')
           line([col col],[row-L row+L],'Color','k')
           line([col+L col-L],[row row],'Color','k')
        end
        if belowChanceI(row,col) == 1
           line([col-L col+L],[row-L row+L],'Color','k')
           line([col+L col-L],[row-L row+L],'Color','k')
           line([col col],[row-L row+L],'Color','k')
           line([col+L col-L],[row row],'Color','k')
        end
    end
end
%% calculate correlation between lower and upper triangular vectors
lower_tri = [];
upper_tri = [];

for i = 2:size(reshaped_ranked_avg,1)
    for j = 1:i-1
        lower_tri = [lower_tri, reshaped_ranked_avg(i,j)];
        upper_tri = [upper_tri, reshaped_ranked_avg(j,i)];
    end
end
[R,P] = corrcoef(lower_tri,upper_tri)
    