%figures 2E and 2F, forced error analysis on data at time to peak for
%regular spiralID decoding

clear all
close all

%load in the values
initializePaths;

nSubjs = 18;
problem = 'SpiralIdentityForcedError';

classifier = 'MaxCorr';
params_desc = '25sensors_75avg_5splits_75repsPerSplit';
filename = [problem '_peak_adjusted_decoding_results.mat']; 
filepath = [quantitativeDataDir filename];

if ~exist(filepath)
    adjust_peaks(problem);
end
load(filepath);
%average confusion_mat
peakI = find(relativeTimes==0);
meanConMats = meanConMats(:,:,peakI);
meanConMatStds = meanConMatStds(:,:,peakI);
allConMats = allConMats(:,:,:,peakI);

%bootstrap accuracies to get CIs across subjects
nBoots = 1000;
nSubj = size(allConMats,3);

colorMark = [250 199 241; 
    221 153 210
   187 213 242
   135 174 211
    159 225 174
    77 189 112
    233 212 173 %
    201 172 111]./255; %

light_inds = [1 3 5 7];
dark_inds = [2 4 6 8];

%get an RDM for each individual subject
nSubj_RDM = size(allConMats,3);
for iRDM = 1: nSubj_RDM
    indiv_vals = squeeze(allConMats(:,:,iRDM));
    lowerTriVec_indiv = [indiv_vals(2:8,1); indiv_vals(3:8,2); indiv_vals(4:8,3);...
        indiv_vals(5:8,4); indiv_vals(6:8,5); indiv_vals(7:8,6);...
        indiv_vals(8,7)]';
    upperTriVec_indiv = [indiv_vals(1,2:8) indiv_vals(2,3:8) indiv_vals(3,4:8)...
        indiv_vals(4,5:8) indiv_vals(5,6:8) indiv_vals(6,7:8)...
        indiv_vals(7,8:8)];
    meanDists_indiv(iRDM,:) = mean([lowerTriVec_indiv; upperTriVec_indiv]);
    raw_dists_indiv(iRDM,1) = meanDists_indiv(iRDM,1);%2 3 4 5 6 7; 1 2 3 4 5 6 %PINK
    raw_dists_indiv(iRDM,2) = meanDists_indiv(iRDM,14);%2 3 4 5; 1 2 3 4%BLUE
    raw_dists_indiv(iRDM,3) = meanDists_indiv(iRDM,23); %2 3; 1 2%GREEN
    raw_dists_indiv(iRDM,4) = meanDists_indiv(iRDM,28);%ORANGE
    indivRDM_noMean(:,:,iRDM)=(1-mat2gray(indiv_vals))+0.01;
    indivRDM(iRDM,:) = (1-mat2gray(meanDists_indiv(iRDM,:)))+0.01; %NEEDS TO BE NOT ZERO
    dists_indiv(iRDM,1) = indivRDM(iRDM,1);%2 3 4 5 6 7; 1 2 3 4 5 6 %PINK
    dists_indiv(iRDM,2) = indivRDM(iRDM,14);%2 3 4 5; 1 2 3 4%BLUE
    dists_indiv(iRDM,3) = indivRDM(iRDM,23); %2 3; 1 2%GREEN
    dists_indiv(iRDM,4) = indivRDM(iRDM,28);%ORANGE
end
dists_indiv = dists_indiv-0.01;
%get an MDS for each individual subject

%get an MDS for the average RDM across subjects RDMs
meanRDM_unFlipped = mean(1-(indivRDM-0.01));
%renormalize over the whole RDM
meanRDM = (1-mat2gray(meanRDM_unFlipped)); 

RDMStruct.RDM =meanRDM+0.01; %NEEDS TO BE NOT ZERO
RDMStruct.name = 'test';
RDMStruct.color = [0 0 0];

%plot RDM distances between the two luminance levels correlated to
%concordance across luminances
dists(1) = RDMStruct.RDM(1);%2 3 4 5 6 7; 1 2 3 4 5 6 %PINK
dists(2) = RDMStruct.RDM(14);%2 3 4 5; 1 2 3 4%BLUE
dists(3) = RDMStruct.RDM(23); %2 3; 1 2%GREEN
dists(4) = RDMStruct.RDM(28);%ORANGE
dists = dists-0.01;

%% decoding confusion across luminance versus concordance plot
colorMark = [250 199 241; 
    221 153 210
   187 213 242
   135 174 211
    159 225 174
    77 189 112
    233 212 173 %
    201 172 111]./255; %

% The following two lines generate concordances from color naming data:
% Subjects are shown colors three times, and concordance is calculated
% using one of their trials, randomly selected for each color, so every run
% will produce slightly different concordances
concordMat = colorNamingConcordance();
concordance = sum(concordMat,2)' / size(concordMat,2);

% The reported concordance values were: [0.5571,0.8571,0.8857,0.3857]
% running the previous lines do not significantly change the reported
% results

figure3 = figure('Color',[1 1 1]);
hold on

sem_dists = std(dists_indiv)/sqrt(nSubj_RDM);

errorbar(concordance,dists, sem_dists,sem_dists,'k.')
for jnd = 1:4
    h(jnd) = scatter(concordance(jnd),dists(jnd), 70); 
    set(h(jnd), 'markerfacecolor', colorMark(jnd*2,:));
    set(h(jnd), 'markeredgecolor', [0 0 0]);
    hold on
end
[coeffs st] = polyfit(concordance, dists, 1);
% Get fitted values
fittedX = linspace(min(concordance),max(concordance), 200);
fittedY = polyval(coeffs, fittedX);
% Plot the fitted line
plot(fittedX, fittedY, 'k-', 'LineWidth', 2);
axis('square')
xlabel('concordance')
ylabel('RDM dists')
title('RDM of spiral ID errors correlation w/concordance')
set(gca, 'YDir','reverse')

%does color naming concordance significantly correlate with decoding 
%confusion across luminance levels?
CNC18 = repmat(concordance,18,1);
[r_CorrCoef_ALL p_CorrCoef_ALL]=corrcoef(CNC18, dists_indiv)

text(0.8,0.9,['r=' num2str(r_CorrCoef_ALL(1,2))])
text(0.8,0.95,['p=' num2str(p_CorrCoef_ALL(1,2))])

%stats on decoding confusion across luminance for warm vs cool
groupWC={'warm','cool','cool','warm'};
%regular ANOVA
p_ANOVA_WarmCool_RDM = anova1(dists_indiv,groupWC,'on')
%kruskal-wallis test 
[p_ANOVA_WarmCool_RDMKW,~,stats] = kruskalwallis(dists_indiv,groupWC,'on')
[c,m,h,gnames] = multcompare(stats)
warmRDM = mean([dists_indiv(:,1),dists_indiv(:,4)],2);
coolRDM = mean(dists_indiv(:,2:3),2);
p = signrank(warmRDM,coolRDM)
