%Creates figures 3a-c
%Gets RDMs from the forced error classifier at each time bin, compares them
%to three models
%Shridhar Singh

close all
clearvars

initializePaths;

problem = 'SpiralIdentityForcedError';

classifier = 'MaxCorr';
params_desc = '25sensors_75avg_5splits_75repsPerSplit';

peakAdjustFilename = [problem '_peak_adjusted_decoding_results.mat']; 
peakAdjustFilepath = [quantitativeDataDir peakAdjustFilename];

if ~exist(peakAdjustFilepath,'file')
    adjust_peaks(problem);
end

load(peakAdjustFilepath,'allConMats','relativeTimes');
nTimePts = size(allConMats,4);
nSubjs = size(allConMats,3);

%% get RDMs and separate values that will be compared to models

for iTime = 1:nTimePts
    thisAll_BySubj = allConMats(:,:,:,iTime);

    %get an RDM for each individual subject
    nSubj_RDM = size(thisAll_BySubj,3);
    for iRDM = 1: nSubj_RDM
        indiv_vals = squeeze(thisAll_BySubj(:,:,iRDM));
        lowerTriVec_indiv = [indiv_vals(2:8,1); indiv_vals(3:8,2); indiv_vals(4:8,3);...
            indiv_vals(5:8,4); indiv_vals(6:8,5); indiv_vals(7:8,6);...
            indiv_vals(8,7)]';
        upperTriVec_indiv = [indiv_vals(1,2:8) indiv_vals(2,3:8) indiv_vals(3,4:8)...
            indiv_vals(4,5:8) indiv_vals(5,6:8) indiv_vals(6,7:8)...
            indiv_vals(7,8:8)];
        meanDists_indiv(iRDM,:) = mean([lowerTriVec_indiv; upperTriVec_indiv]);
        indivRDM(iRDM,:) = (1-mat2gray(meanDists_indiv(iRDM,:)))+0.01; %NEEDS TO BE NOT ZERO
        indivRDMs(iRDM,iTime,:) = indivRDM(iRDM,:);

    end
    meanRDM_unFlipped = mean(1-(indivRDM-0.01));
    %renormalize over the whole RDM
    meanRDMs(:,iTime) = 1-mat2gray(meanRDM_unFlipped);
end

ref_RDM = {'LpLp','LpDp','LpLb','LpDb','LpLg','LpDg','LpLo','LpDo';...
    'DpLp','DpDp','DpLb','DpDb','DpLg','DpDg','DpLo','DpDo';...
    'LbLp','LbDp','LbLb','LbDb','LbLg','LbDg','LbLo','LbDo';...
    'DbLp','DbDp','DbLb','DbDb','DbLg','DbDg','DbLo','DbDo';...
    'LgLp','LgDp','LgLb','LgDb','LgLg','LgDg','LgLo','LgDo';...
    'DgLp','DgDp','DgLb','DgDb','DgLg','DgDg','DgLo','DgDo';...
    'LoLp','LoDp','LoLb','LoDb','LoLg','LoDg','LoLo','LoDo';...
    'DoLp','DoDp','DoLb','DoDb','DoLg','DoDg','DoLo','DoDo'};

lowerTriVec_ref = [ref_RDM(2:8,1); ref_RDM(3:8,2); ref_RDM(4:8,3);...
            ref_RDM(5:8,4); ref_RDM(6:8,5); ref_RDM(7:8,6);...
            ref_RDM(8,7)]';
upperTriVec_ref = [ref_RDM(1,2:8) ref_RDM(2,3:8) ref_RDM(3,4:8)...
            ref_RDM(4,5:8) ref_RDM(5,6:8) ref_RDM(6,7:8)...
            ref_RDM(7,8:8)];

iLpDp = find(strcmp(upperTriVec_ref,'LpDp')); 
iLpLb = find(strcmp(upperTriVec_ref,'LpLb')); 
iLpDb = find(strcmp(upperTriVec_ref,'LpDb')); 
iLpLg = find(strcmp(upperTriVec_ref,'LpLg')); 
iLpDg = find(strcmp(upperTriVec_ref,'LpDg')); 
iLpLo = find(strcmp(upperTriVec_ref,'LpLo')); 
iLpDo = find(strcmp(upperTriVec_ref,'LpDo')); 

iDpLb = find(strcmp(upperTriVec_ref,'DpLb'));
iDpDb = find(strcmp(upperTriVec_ref,'DpDb'));
iDpLg = find(strcmp(upperTriVec_ref,'DpLg'));
iDpDg = find(strcmp(upperTriVec_ref,'DpDg'));
iDpLo = find(strcmp(upperTriVec_ref,'DpLo'));
iDpDo = find(strcmp(upperTriVec_ref,'DpDo'));

iLbDb = find(strcmp(upperTriVec_ref,'LbDb')); 
iLbLg = find(strcmp(upperTriVec_ref,'LbLg'));
iLbDg = find(strcmp(upperTriVec_ref,'LbDg')); 
iLbLo = find(strcmp(upperTriVec_ref,'LbLo')); 
iLbDo = find(strcmp(upperTriVec_ref,'LbDo')); 

iDbLg = find(strcmp(upperTriVec_ref,'DbLg'));
iDbDg = find(strcmp(upperTriVec_ref,'DbDg'));
iDbLo = find(strcmp(upperTriVec_ref,'DbLo'));
iDbDo = find(strcmp(upperTriVec_ref,'DbDo'));

iLgDg = find(strcmp(upperTriVec_ref,'LgDg'));
iLgLo = find(strcmp(upperTriVec_ref,'LgLo'));
iLgDo = find(strcmp(upperTriVec_ref,'LgDo'));

iDgLo = find(strcmp(upperTriVec_ref,'DgLo'));
iDgDo = find(strcmp(upperTriVec_ref,'DgDo'));

iLoDo = find(strcmp(upperTriVec_ref,'LoDo'));

withinHueSubjVec(:,:,1) = indivRDMs(:,:,iLbDb);
withinHueSubjVec(:,:,2) = indivRDMs(:,:,iLgDg);
withinHueSubjVec(:,:,3) = indivRDMs(:,:,iLpDp);
withinHueSubjVec(:,:,4) = indivRDMs(:,:,iLoDo);

withinHueMeanVec(:,1) = meanRDMs(iLbDb,:);
withinHueMeanVec(:,2) = meanRDMs(iLgDg,:);
withinHueMeanVec(:,3) = meanRDMs(iLpDp,:);
withinHueMeanVec(:,4) = meanRDMs(iLoDo,:);

withinLumSubjVec(:,:,1) = indivRDMs(:,:,iLpLo);
withinLumSubjVec(:,:,2) = indivRDMs(:,:,iDpDo);
withinLumSubjVec(:,:,3) = indivRDMs(:,:,iLbLg);
withinLumSubjVec(:,:,4) = indivRDMs(:,:,iDbDg);

withinLumMeanVec(:,1) = meanRDMs(iLpLo,:);
withinLumMeanVec(:,2) = meanRDMs(iDpDo,:);
withinLumMeanVec(:,3) = meanRDMs(iLbLg,:);
withinLumMeanVec(:,4) = meanRDMs(iDbDg,:);

lumSepSame = cat(3,indivRDMs(:,:,iLpLo),indivRDMs(:,:,iLpLb),indivRDMs(:,:,iLpLo),...
    indivRDMs(:,:,iDpDb),indivRDMs(:,:,iDpDg),indivRDMs(:,:,iDpDo),...
    indivRDMs(:,:,iLbLg),indivRDMs(:,:,iLbLo),...
    indivRDMs(:,:,iDbDg),indivRDMs(:,:,iDbDo),...
    indivRDMs(:,:,iLgLo),indivRDMs(:,:,iDgDo));

lumSepDiff = cat(3,indivRDMs(:,:,iLpDp),indivRDMs(:,:,iLpDb),indivRDMs(:,:,iLpDg),indivRDMs(:,:,iLpDo),...
    indivRDMs(:,:,iDpLb),indivRDMs(:,:,iDpLg),indivRDMs(:,:,iDpLo),...
    indivRDMs(:,:,iLbDb),indivRDMs(:,:,iLbDg),indivRDMs(:,:,iLbDo),...
    indivRDMs(:,:,iDbLg),indivRDMs(:,:,iDbLo),...
    indivRDMs(:,:,iLgDg),indivRDMs(:,:,iLgDo),indivRDMs(:,:,iDgLo),indivRDMs(:,:,iLoDo));

lumSepSubjVec = cat(3,lumSepSame,lumSepDiff);

%% setup
ymax = 0.7;
userOptionsColors = defineUserOptions_MEG2018();
userOptionsColors.RDMcorrelationType='Kendall_taua'; %use this to compare models
userOptionsColors.RDMcorrelationType='Kendall_taua';
userOptionsColors.RDMrelatednessTest = 'subjectRFXsignedRank';
userOptionsColors.RDMrelatednessThreshold = 0.05;
userOptionsColors.RDMrelatednessMultipleTesting = 'FDR';
userOptionsColors.saveFiguresPDF = 1;
userOptionsColors.candRDMdifferencesTest = 'subjectRFXsignedRank';
userOptionsColors.candRDMdifferencesThreshold = 0.05;
userOptionsColors.candRDMdifferencesMultipleTesting = 'FDR';
userOptionsColors.plotpValues = '=';
userOptionsColors.barsOrderedByRDMCorr=true;
userOptionsColors.resultsPath = userOptionsColors.rootPath;
userOptionsColors.figureIndex = [8 9];
userOptionsColors.figure1filename = 'compareRefRDM2candRDMs_barGraph_simulatedITasRef';
userOptionsColors.figure2filename = 'compareRefRDM2candRDMs_pValues_simulatedITasRef';

localOptionsIndiv.figureNumber = 6;

%% correlations for lum separation

lumSepModelVec = logical([0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1])';
randVec = logical(randi(2,1,28)-1)';

models(1).RDM = lumSepModelVec;
models(1).name = 'Luminance Separation Model';
models(1).color = [0 0 0];
models(2).RDM = randVec;
models(2).name = 'Random Model 1';
models(2).color = [0 0 0];
clear modelVec
modelVec(:,1) = models(1).RDM;
modelVec(:,2) = models(2).RDM;

timeStarts = relativeTimes;

for iSubj = 1:nSubjs
    subjData = squeeze(lumSepSubjVec(iSubj,:,:));
    for iDist = 1:size(subjData,2)
        a_binned(:,iSubj,iDist) = subjData(:,iDist);
    end
end

clear subjectVecs noiseCeiling corrP_toMEG corrRs_toMEG corrSE
for timePoint = 1 : nTimePts
    for iSubj = 1:nSubjs
        subjectRDMs(:,iSubj)=squeeze(a_binned(timePoint,iSubj,:));
    end
    stats_p_r=rsa.compareRefRDM2candRDMs_customVec(subjectRDMs, modelVec, userOptionsColors);
    noiseCeiling(timePoint,:) = stats_p_r.ceiling;
    corrP_toMEG(timePoint,:) = stats_p_r.candRelatedness_p;
    corrRs_toMEG(timePoint,:,:) = stats_p_r.candRelatedness_r;    
    clear subjectRDMs
end

%% plot lum separation correlations
figure1 = figure(1)
avgVal=5;
set(figure1,'Color',[1 1 1])
x2 = [timeStarts, fliplr(timeStarts)];
inBetween = [noiseCeiling(:,2)', fliplr(noiseCeiling(:,1)')];
f = fill(x2, inBetween, [0.85 0.85 0.85]);
set(f,'EdgeColor','none')
y_range =  [-0.25    ymax];
% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
hold on

plot(timeStarts,mean(corrRs_toMEG(:,:,1),2),'k','LineWidth',1)

xlim([timeStarts(1), timeStarts(end)])
line(timeStarts, zeros(1, numel(timeStarts)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
yticks([-0.2,0,0.4])
ylim(y_range)
set(gca,'fontsize',10);
grid off
box off
scale_factor = 1.5;
title('Luminance Separation Model')
xlabel('Time relative to peak (ms)')
ylabel("Kendall's tau")
sigStreakCount=0;
nConsec = 5;

[~,~,~, adj_p] = fdr_bh(corrP_toMEG(:,1),0.05);
lumSepSigs = zeros(1,148);
for t = 1:numel(timeStarts)
    if adj_p(t) < (0.05)
%         sigStreakCount = sigStreakCount+1;
        full_bin = timeStarts(t-sigStreakCount) - avgVal/2 : timeStarts(t) + avgVal/2;
        line(full_bin, (y_range(1) + 0.025) * ones(1, numel(full_bin)), 'LineWidth', 1 * scale_factor, 'Color', [0 0 0]); 
        lumSepSigs(t-sigStreakCount:t)
%     else
%         if sigStreakCount >= nConsec
%            full_bin = timeStarts(t-sigStreakCount) - avgVal/2 : timeStarts(t) + avgVal/2;
%            line(full_bin, (y_range(1) + 0.025) * ones(1, numel(full_bin)), 'LineWidth', 1 * scale_factor, 'Color', [0 0 0]); 
%            lumSepSigs(t-sigStreakCount:t)
%         end
%         sigStreakCount=0;
    end
   
end

%print('-f1',[figuresDir 'Fig3A.png'],'-dpng','-r300')

%% correlation for withinLum

withinLumModelVec = logical([0 0 1 1])';
randVec = logical(randi(2,1,4)-1)';

models(1).RDM = withinLumModelVec;
models(1).name = 'Within Lum Model';
models(1).color = [0 0 0];
models(2).RDM = randVec;
models(2).name = 'Random Model 1';
models(2).color = [0 0 0];

clear modelVec
modelVec(:,1) = models(1).RDM;
modelVec(:,2) = models(2).RDM;

nSubjs = size(withinLumSubjVec,1);
all_BySubj2 = permute(allConMats,[3,4,1,2]);

clear a_binned
for iSubj = 1:nSubjs
    subjData = squeeze(withinLumSubjVec(iSubj,:,:));
    for iDist = 1:size(subjData,2)
        a_binned(:,iSubj,iDist) = subjData(:,iDist);
    end
end

clear subjectVecs noiseCeiling corrP_toMEG corrRs_toMEG subjectRDMs 
for timePoint = 1 : nTimePts
    for iSubj = 1:nSubjs
        %bin every 5 ms
        subjectRDMs(:,iSubj)=squeeze(a_binned(timePoint,iSubj,:));
    end
    stats_p_r=rsa.compareRefRDM2candRDMs_customVec(subjectRDMs, modelVec, userOptionsColors);
    noiseCeiling(timePoint,:) = stats_p_r.ceiling;
    corrP_toMEG(timePoint,:) = stats_p_r.candRelatedness_p;
    corrRs_toMEG(timePoint,:,:) = stats_p_r.candRelatedness_r;
    clear subjectRDMs
end
%% plot withinLum

figure2 = figure(2)
set(figure2,'Color',[1 1 1])
x2 = [timeStarts, fliplr(timeStarts)];
inBetween = [noiseCeiling(:,2)', fliplr(noiseCeiling(:,1)')];
f = fill(x2, inBetween, [0.85 0.85 0.85]);
set(f,'EdgeColor','none')
y_range =  [-0.25    ymax];

% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
hold on
plot(timeStarts,mean(corrRs_toMEG(:,:,1),2),'k','LineWidth',1)

xlim([timeStarts(1), timeStarts(end)])
line(timeStarts, zeros(1, numel(timeStarts)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);

ylim(y_range)
yticks([-0.2,0,0.4])
xticks([-200,0,200,400])

set(gca,'fontsize',10);
grid off
box off
scale_factor = 1.5;
title('Within Lum')

sigStreakCount = 0;
nConsec = 5;

[~,~,~, adj_p] = fdr_bh(corrP_toMEG(:,1),0.05);
for t = 1:numel(timeStarts)
    if adj_p(t) < 0.05
%         sigStreakCount = sigStreakCount+1;
        full_bin = timeStarts(t-sigStreakCount) - avgVal/2 : timeStarts(t) + avgVal/2;
        line(full_bin, (y_range(1) + 0.025) * ones(1, numel(full_bin)), 'LineWidth', 1 * scale_factor, 'Color', [0 0 0]); 
%     else
%         if sigStreakCount >= nConsec
%            full_bin = timeStarts(t-sigStreakCount) - avgVal/2 : timeStarts(t) + avgVal/2;
%            line(full_bin, (y_range(1) + 0.025) * ones(1, numel(full_bin)), 'LineWidth', 1 * scale_factor, 'Color', [0 0 0]); 
%         end
%         sigStreakCount=0;
    end
end

%print('-f2',[figuresDir 'Fig3C.png'],'-dpng','-r300')


%% correlations for withinHue
withinHueModelVec = logical([0 0 1 1])';
randVec = logical(randi(2,1,4)-1)';

models(1).RDM = withinHueModelVec;
models(1).name = 'Within Hue Model';
models(1).color = [0 0 0];
models(2).RDM = randVec;
models(2).name = 'Random Model 1';
models(2).color = [0 0 0];

clear modelVec
modelVec(:,1) = models(1).RDM;
modelVec(:,2) = models(2).RDM;

clear a_binned
for iSubj = 1:nSubjs
    subjData = squeeze(withinHueSubjVec(iSubj,:,:));
    for iDist = 1:size(subjData,2)
        a_binned(:,iSubj,iDist) = subjData(:,iDist);
    end
end

clear subjectVecs noiseCeiling corrP_toMEG corrRs_toMEG subjectRDMs 
for timePoint = 1 : nTimePts
    for iSubj = 1:nSubjs
        subjectRDMs(:,iSubj)=squeeze(a_binned(timePoint,iSubj,:));
    end
    stats_p_r=rsa.compareRefRDM2candRDMs_customVec(subjectRDMs, modelVec, userOptionsColors);

    stats_p_r_allTimes(timePoint) = stats_p_r;
    noiseCeiling(timePoint,:) = stats_p_r.ceiling;
    corrP_toMEG(timePoint,:) = stats_p_r.candRelatedness_p;
    corrRs_toMEG(timePoint,:,:) = stats_p_r.candRelatedness_r;
    clear subjectRDMs
end

%% plot withinHue

figure3 = figure(3)
set(figure3,'Color',[1 1 1])
x2 = [timeStarts, fliplr(timeStarts)];
inBetween = [noiseCeiling(:,2)', fliplr(noiseCeiling(:,1)')];
f = fill(x2, inBetween, [0.85 0.85 0.85]);
set(f,'EdgeColor','none')
y_range =  [-0.25    ymax];

% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);

hold on
plot(timeStarts,mean(corrRs_toMEG(:,:,1),2),'k','LineWidth',1)

xlim([timeStarts(1), timeStarts(end)])
xticks([-200,0,200,400])

line(timeStarts, zeros(1, numel(timeStarts)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
yticks([-0.2 0 0.4])

ylim(y_range)
set(gca,'fontsize',10);
grid off
box off
scale_factor = 1.5;
title('WithinHue')

sigStreakCount=0;
nConsec = 5;
avgVal = 5;

[~,~,~, adj_p] = fdr_bh(corrP_toMEG(:,1),0.05);
for t = 1:numel(timeStarts)
    if adj_p(t) < 0.05
%         sigStreakCount = sigStreakCount+1;
        full_bin = timeStarts(t-sigStreakCount) - avgVal/2 : timeStarts(t) + avgVal/2;
        line(full_bin, (y_range(1) + 0.025) * ones(1, numel(full_bin)), 'LineWidth', 1 * scale_factor, 'Color', [0 0 0]); 
%     else
%         if sigStreakCount >= nConsec
%            full_bin = timeStarts(t-sigStreakCount) - avgVal/2 : timeStarts(t) + avgVal/2;
%            line(full_bin, (y_range(1) + 0.025) * ones(1, numel(full_bin)), 'LineWidth', 1 * scale_factor, 'Color', [0 0 0]); 
%         end
%         sigStreakCount=0;
    end
    
end

%print('-f3',[figuresDir 'Fig3B.png'],'-dpng','-r300')
