% The MDS plots were mostly consistent with how the hues were arranged
% circularly. This script is a follow up to check the similarity of hues to
% one another
% Shridhar Singh 9-16-2020

clearvars
close all

%% load the variables

initializePaths

problem = 'SpiralIdentityForcedError';
peakAdjustFilename = [problem '_peak_adjusted_decoding_results.mat']; 
peakAdjustFilepath = [quantitativeDataDir peakAdjustFilename];
load(peakAdjustFilepath)
%% things for later
nSubjs = size(diagConMat,2);
nTimePts = size(diagConMat,3);
nColors = size(diagConMat,1);
nRDM_vals = (nColors^2) / 2 - nColors / 2;

ref_RDM = {'LpLp','LpDp','LpLb','LpDb','LpLg','LpDg','LpLo','LpDo';...
    'DpLp','DpDp','DpLb','DpDb','DpLg','DpDg','DpLo','DpDo';...
    'LbLp','LbDp','LbLb','LbDb','LbLg','LbDg','LbLo','LbDo';...
    'DbLp','DbDp','DbLb','DbDb','DbLg','DbDg','DbLo','DbDo';...
    'LgLp','LgDp','LgLb','LgDb','LgLg','LgDg','LgLo','LgDo';...
    'DgLp','DgDp','DgLb','DgDb','DgLg','DgDg','DgLo','DgDo';...
    'LoLp','LoDp','LoLb','LoDb','LoLg','LoDg','LoLo','LoDo';...
    'DoLp','DoDp','DoLb','DoDb','DoLg','DoDg','DoLo','DoDo'};

lowerTriVec_ref = [ref_RDM(2:8,1); ref_RDM(3:8,2); ref_RDM(4:8,3);...
            ref_RDM(5:8,4); ref_RDM(6:8,5); ref_RDM(7:8,6);...
            ref_RDM(8,7)]';
upperTriVec_ref = [ref_RDM(1,2:8) ref_RDM(2,3:8) ref_RDM(3,4:8)...
            ref_RDM(4,5:8) ref_RDM(5,6:8) ref_RDM(6,7:8)...
            ref_RDM(7,8:8)];

        
colorMark = [250 199 241; 
    221 153 210
   187 213 242
   135 174 211
    159 225 174
    77 189 112
    233 212 173 %
    201 172 111]./255; %

%% get RDM distances

for iTime = 1:nTimePts
    for iRDM = 1: nSubjs
        indiv_vals = squeeze(allConMats(:,:,iRDM,iTime));
        lowerTriVec_indiv = [indiv_vals(2:8,1); indiv_vals(3:8,2); indiv_vals(4:8,3);...
            indiv_vals(5:8,4); indiv_vals(6:8,5); indiv_vals(7:8,6);...
            indiv_vals(8,7)]';
        
        upperTriVec_indiv = [indiv_vals(1,2:8) indiv_vals(2,3:8) indiv_vals(3,4:8)...
            indiv_vals(4,5:8) indiv_vals(5,6:8) indiv_vals(6,7:8)...
            indiv_vals(7,8:8)];
        
        meanDists_indiv(:,iRDM,iTime) = mean([lowerTriVec_indiv; upperTriVec_indiv]);
        indivRDM_noMean(:,:,iRDM,iTime)=(1-mat2gray(indiv_vals))+0.01;
        indivRDM(:,iRDM,iTime) = (1-mat2gray(meanDists_indiv(:,iRDM,iTime)))+0.01; %NEEDS TO BE NOT ZERO
    end
end

meanRDM_unFlipped = squeeze(mean(1-(indivRDM-0.01),2));
meanRDM = squeeze((1-mat2gray(meanRDM_unFlipped))); 

%% get MDS distances - 3D
% toolboxRoot = [rootDir,'/users/rosenthalia/MEG_Project2018/Intermediates_Study/Analysis_Code/Sensor_wise_decoding']; addpath(genpath(toolboxRoot));
userOptions = defineUserOptions_MEG2018();
userOptions.dotSize = 20;
userOptions.displayFigures = 0;
userOptionsColors = userOptions;

localOptions.figI_textLabels = nan;
localOptions.figI_shepardPlots = [];

point_coords3D = zeros(nColors,3,nTimePts);
for i = 1:size(meanRDM,2)
    RDMStruct.RDM =meanRDM(:,i)+0.01; %NEEDS TO BE NOT ZERO
    RDMStruct.name = 'test';
    RDMStruct.color = [0 0 0];
    [~,~,point_coords3D(:,:,i)] = rsa.MDSConditions_MEG2018_3D(RDMStruct,userOptionsColors,localOptions);
end

%% compute distances from pink - 3D
LpBasisDists = zeros(nColors/2-1,nTimePts);
DpBasisDists = zeros(nColors/2-1,nTimePts);

lightColorsI = [3,5,7];
darkColorsI = [4,6,8];
for iTime = 1:nTimePts
    for iColor = 1:nColors/2-1
        lightI = lightColorsI(iColor);
        LpBasisDists(iColor,iTime) = norm(point_coords3D(1,:,iTime) - point_coords3D(lightI,:,iTime));
        darkI = darkColorsI(iColor);
        DpBasisDists(iColor,iTime) = norm(point_coords3D(2,:,iTime) - point_coords3D(darkI,:,iTime));
    end
end

[LpDistsRank,LpBasisRankI] = sort(LpBasisDists);
[DpBasisRank,DpBasisRankI] = sort(DpBasisDists);

lightColors = colorMark([3,5,7],:);
darkColors = colorMark([4,6,8],:);

for i = 1:nTimePts
   LpBasisColors(:,:,i) = lightColors(LpBasisRankI(:,i),:);
   DpBasisColors(:,:,i) = darkColors(DpBasisRankI(:,i),:);
end    

%% plot the light pink basis - 3D

y_vals = repmat([3;2;1],size(relativeTimes));

lineWidth = 10;
figure
for iTime = 1:size(LpBasisColors,3)
    line([relativeTimes(iTime)-2.5,relativeTimes(iTime)+2.5],[4,4],...
        'Color',colorMark(1,:),'LineWidth',lineWidth)
    for i = 1:size(LpBasisColors,1)
        hold on
        line([relativeTimes(iTime)-2.5,relativeTimes(iTime)+2.5],[y_vals(i,iTime),y_vals(i,iTime)],...
            'Color',LpBasisColors(i,:,iTime),'LineWidth',lineWidth)
    end
end
ylim([1,50])
% xlim([-100,100])
xlim([relativeTimes(1),relativeTimes(end)])
xlabel('Time (ms) relative to peak')
ylabel('MDS distance from pink rank')
title('Rank order of MDS distance from light pink 3D')

%% plot the dark pink basis - 3D

y_vals = repmat([3;2;1],size(relativeTimes));

lineWidth = 10;
figure
for iTime = 1:size(LpBasisColors,3)
    line([relativeTimes(iTime)-2.5,relativeTimes(iTime)+2.5],[4,4],...
        'Color',colorMark(2,:),'LineWidth',lineWidth)
    for i = 1:size(LpBasisColors,1)
        hold on
        line([relativeTimes(iTime)-2.5,relativeTimes(iTime)+2.5],[y_vals(i,iTime),y_vals(i,iTime)],...
            'Color',DpBasisColors(i,:,iTime),'LineWidth',lineWidth)
    end
end
ylim([1,50])
% xlim([-100,100])
xlim([relativeTimes(1),relativeTimes(end)])
xlabel('Time (ms) relative to peak')
ylabel('MDS distance from pink rank')
title('Rank order of MDS distance from light pink 3D')


