%Figure 3d and Supplemental figures, MDS and RDMs from forced error data
%Shridhar Singh and Isabelle Rosenthal

clearvars
close all

%load in the values
initializePaths;

nSubjs = 18;
problem = 'SpiralIdentityForcedError';

peakAdjustFilename = [problem '_peak_adjusted_decoding_results.mat']; 
peakAdjustFilepath = [quantitativeDataDir peakAdjustFilename];

if ~exist(peakAdjustFilepath,'file')
    adjust_peaks(problem);
end

figureSavepath = figuresDir;

MDS_movie = 0;
RDM_movie = 0;
fig3_MDS_save = 0;
MDS_3D_save = 1;
toSave = 1;

userOptionsColors = defineUserOptions_MEG2018();
localOptionsAvg.figureNumber = 1;

%% get RDMs
load(peakAdjustFilepath);
nTimePts = size(meanConMats,3);
meanRDMs = zeros(28,nTimePts);
bootRDMs = zeros(1000,nTimePts,28);
for iTime = 1:nTimePts
    thisConMat = meanConMats(:,:,iTime);
    thisAllConMat = allConMats(:,:,:,iTime);
    thisConMatStd = meanConMatStds(:,:,iTime);
    thisDiagConMat = diagConMat(:,:,iTime);
    thisDiagMean = diag(thisConMat(:,:));
    %get error bars (Standard deviation of normalized individual accuracies)
    thisDiagStd = diag(thisConMatStd(:,:));

    %bootstrap accuracies to get CIs across subjects
    nBoots = 1000;
    nSubj = size(thisAllConMat,3);
    for iBoot = 1:nBoots
        iSubjInds = datasample(1:nSubj, nSubj);
        iDiag = thisDiagConMat(:,iSubjInds);
        avgDiagBoots(iBoot,:) = mean(iDiag,2);
    end
    sorted_AvgDiag = sort(avgDiagBoots);
    lowerDiag = abs(thisDiagMean' - sorted_AvgDiag(25,:));
    upperDiag = abs(thisDiagMean' - sorted_AvgDiag(975,:));

    light_inds = [1 3 5 7];
    dark_inds = [2 4 6 8];

    %get an RDM for each individual subject
    nSubj_RDM = size(thisAllConMat,3);
    for iRDM = 1: nSubj_RDM
        indiv_vals = squeeze(thisAllConMat(:,:,iRDM));
        lowerTriVec_indiv = [indiv_vals(2:8,1); indiv_vals(3:8,2); indiv_vals(4:8,3);...
            indiv_vals(5:8,4); indiv_vals(6:8,5); indiv_vals(7:8,6);...
            indiv_vals(8,7)]';
        upperTriVec_indiv = [indiv_vals(1,2:8) indiv_vals(2,3:8) indiv_vals(3,4:8)...
            indiv_vals(4,5:8) indiv_vals(5,6:8) indiv_vals(6,7:8)...
            indiv_vals(7,8:8)];
        meanDists_indiv(iRDM,:) = mean([lowerTriVec_indiv; upperTriVec_indiv]);
        indivRDM(iRDM,:) = (1-mat2gray(meanDists_indiv(iRDM,:)))+0.01; %NEEDS TO BE NOT ZERO
        indivRDMs(iRDM,iTime,:) = indivRDM(iRDM,:);
    end
    
    %renormalize over the whole RDM: values are normalized from 0-1 for each time  
    meanRDM_unFlipped = mean(1-(indivRDM-0.01));
    meanRDMs(:,iTime) = 1-mat2gray(meanRDM_unFlipped);
    meanDists(:,iTime) = mean(meanDists_indiv);
end

%the values are normalized from 0-1 over all times
meanRDMs_allNorm = 1-mat2gray(meanDists);

%% make RDM movie

if RDM_movie

ref_RDM = {'LpLp','LpDp','LpLb','LpDb','LpLg','LpDg','LpLo','LpDo';...
           'DpLp','DpDp','DpLb','DpDb','DpLg','DpDg','DpLo','DpDo';...
           'LbLp','LbDp','LbLb','LbDb','LbLg','LbDg','LbLo','LbDo';...
           'DbLp','DbDp','DbLb','DbDb','DbLg','DbDg','DbLo','DbDo';...
           'LgLp','LgDp','LgLb','LgDb','LgLg','LgDg','LgLo','LgDo';...
           'DgLp','DgDp','DgLb','DgDb','DgLg','DgDg','DgLo','DgDo';...
           'LoLp','LoDp','LoLb','LoDb','LoLg','LoDg','LoLo','LoDo';...
           'DoLp','DoDp','DoLb','DoDb','DoLg','DoDg','DoLo','DoDo'};

lowerTriVec_ref = [ref_RDM(2:8,1); ref_RDM(3:8,2); ref_RDM(4:8,3);...
            ref_RDM(5:8,4); ref_RDM(6:8,5); ref_RDM(7:8,6);...
            ref_RDM(8,7)]';
upperTriVec_ref = [ref_RDM(1,2:8) ref_RDM(2,3:8) ref_RDM(3,4:8)...
            ref_RDM(4,5:8) ref_RDM(5,6:8) ref_RDM(6,7:8)...
            ref_RDM(7,8:8)];

iLpDp = find(strcmp(upperTriVec_ref,'LpDp')); 
iLpLb = find(strcmp(upperTriVec_ref,'LpLb')); 
iLpDb = find(strcmp(upperTriVec_ref,'LpDb')); 
iLpLg = find(strcmp(upperTriVec_ref,'LpLg')); 
iLpDg = find(strcmp(upperTriVec_ref,'LpDg')); 
iLpLo = find(strcmp(upperTriVec_ref,'LpLo')); 
iLpDo = find(strcmp(upperTriVec_ref,'LpDo')); 

iDpLb = find(strcmp(upperTriVec_ref,'DpLb'));
iDpDb = find(strcmp(upperTriVec_ref,'DpDb'));
iDpLg = find(strcmp(upperTriVec_ref,'DpLg'));
iDpDg = find(strcmp(upperTriVec_ref,'DpDg'));
iDpLo = find(strcmp(upperTriVec_ref,'DpLo'));
iDpDo = find(strcmp(upperTriVec_ref,'DpDo'));

iLbDb = find(strcmp(upperTriVec_ref,'LbDb')); 
iLbLg = find(strcmp(upperTriVec_ref,'LbLg'));
iLbDg = find(strcmp(upperTriVec_ref,'LbDg')); 
iLbLo = find(strcmp(upperTriVec_ref,'LbLo')); 
iLbDo = find(strcmp(upperTriVec_ref,'LbDo')); 

iDbLg = find(strcmp(upperTriVec_ref,'DbLg'));
iDbDg = find(strcmp(upperTriVec_ref,'DbDg'));
iDbLo = find(strcmp(upperTriVec_ref,'DbLo'));
iDbDo = find(strcmp(upperTriVec_ref,'DbDo'));

iLgDg = find(strcmp(upperTriVec_ref,'LgDg'));
iLgLo = find(strcmp(upperTriVec_ref,'LgLo'));
iLgDo = find(strcmp(upperTriVec_ref,'LgDo'));

iDgLo = find(strcmp(upperTriVec_ref,'DgLo'));
iDgDo = find(strcmp(upperTriVec_ref,'DgDo'));

iLoDo = find(strcmp(upperTriVec_ref,'LoDo'));

rdm = meanRDMs_allNorm;

RDMmats = zeros(8,8,size(rdm,2));
for i = 1:size(RDMmats,3)
RDMmats(2,1:1,i) = [rdm(iLoDo,i)];
RDMmats(3,1:2,i) = [rdm(iLpLo,i), rdm(iLpDo,i)];
RDMmats(4,1:3,i) = [rdm(iDpLo,i), rdm(iDpDo,i), rdm(iLpDp,i)];
RDMmats(5,1:4,i) = [rdm(iLgLo,i), rdm(iLgDo,i), rdm(iLpLg,i), rdm(iDpLg,i)];
RDMmats(6,1:5,i) = [rdm(iDgLo,i), rdm(iDgDo,i), rdm(iLpDg,i), rdm(iDpDg,i), rdm(iLgDg,i)];
RDMmats(7,1:6,i) = [rdm(iLbLo,i), rdm(iLbDo,i), rdm(iLpLb,i), rdm(iDpLb,i),rdm(iLbLg,i),rdm(iLbDg,i)];
RDMmats(8,1:7,i) = [rdm(iDbLo,i), rdm(iDbDo,i), rdm(iLpDb,i),rdm(iDpDb,i),rdm(iDbLg,i),rdm(iDbDg,i),rdm(iLbDb,i)];
end

figure1 = figure('Color',[1 1 1]);
for i = 1:size(rdm,2)
    RDMmat = RDMmats(:,:,i);
    axes1 = axes('Parent',figure1,'Layer','top','YDir','reverse','XTick',[],...
        'YTick',[], 'XLim', [0 size(RDMmat,1)+1], 'YLim', [0 size(RDMmat,2)+1]);
    box(axes1,'on');
    hold(axes1,'on');
    imagesc(RDMmat,'Parent',axes1,[0 1]);

    xlabel('Actual Class','FontSize',18);
    ylabel('Predicted Class','FontSize',18,'Color',[0.15 0.15 0.15]);
    colorbar('peer',axes1);
    title([num2str(relativeTimes(i)) 'ms'], 'FontSize', 16)
    annotation(figure1,'textbox',...
        [0.61 0 0.181300884955752 0.07],...
        'String',{['sampled at individual peak accuracies']},...
        'FontSize', 12, 'FitBoxToText','on', 'LineStyle','none');

    topColor = [0 0 0]/255; %blue
    bottomColor = [21 67 216]/255;[216 50 21]/255; %red



    numVals = size(RDMmat,1);
    chanceVal = 0 %1/(numVals-1); %for forced error
    cmap = create_chanceAligned_colormap(chanceVal, 1, 0, topColor, bottomColor,1);

    colormap(cmap);

    hold on;

    %add grid on
    for row = 0 : 1 : size(RDMmat,1)
      line([0.5, size(RDMmat,1) + .5], [row+.5, row+.5], 'Color', 'k');
    end
    for col = 0 : 1 : size(RDMmat,1)
      line([col+.5, col+.5], [0.5, size(RDMmat,1) + .5], 'Color', 'k');
    end    
    
    M_RDM(i) = getframe(figure1);
    clf
end
close all

if toSave
    v = VideoWriter([movieDir 'RDM_ForcedError_peakAdjust_uniformColorScale.avi']);
    v.FrameRate = 1;
    v.Quality = 100;
    open(v)
    writeVideo(v, M_RDM)
    close(v)
end
end

%% make MDS movie
if MDS_movie
for i = 1:nTimePts
    RDMStruct.RDM =meanRDMs(:,i)+0.01; %NEEDS TO BE NOT ZERO
    RDMStruct.name = 'test';
    RDMStruct.color = [0 0 0];
    [pearsonRLum_indiv, p_pearsonLum_indiv] = rsa.MDSConditions_MEG2018(RDMStruct,userOptionsColors, localOptionsAvg);
    title([num2str(relativeTimes(i)), 'ms'])
    f = gcf;
    M(i) = getframe(f);
end
if toSave
    v = VideoWriter([movieDir,'MDS_ForcedError_peakAdjust.avi']);
    v.FrameRate = 1;
    v.Quality = 100;
    open(v)
    writeVideo(v, M)
    close(v)
end
end
%% Save MDS plots for figure 3
if fig3_MDS_save

MDS_inds = [55,56,57,82,83,84];
for i = 1:numel(MDS_inds)
    localOptionsAvg.figureNumber = i;
    RDMStruct.RDM =meanRDMs(:,MDS_inds(i))+0.01; %NEEDS TO BE NOT ZERO
    RDMStruct.name = 'test';
    RDMStruct.color = [0 0 0];
    [pearsonRLum_indiv(i), p_pearsonLum_indiv(i)] = rsa.MDSConditions_MEG2018(RDMStruct,userOptionsColors, localOptionsAvg);
    saveName = ['MDS_ForcedError_' num2str(relativeTimes(MDS_inds(i))),'ms.png'];
    f = gcf;
    if toSave
        print(f,[figureDir,saveName],'-dpng','-r300')
    end
end

end
%% similar to above but 3D MDS

ViewZ = [0,90;0,0;90,0;180,0;270,0;360,0;360,-90];
OptionZ.FrameRate=30;OptionZ.Duration=10;OptionZ.Periodic=false; 

if MDS_3D_save
MDS_inds = [55,56,57,60,61,62,82,83,84];
for i = 1:numel(MDS_inds)
    localOptionsAvg.figureNumber = i;
    RDMStruct.RDM =meanRDMs(:,MDS_inds(i))+0.01; %NEEDS TO BE NOT ZERO
    RDMStruct.name = 'test';
    RDMStruct.color = [0 0 0];
    [pearsonRLum_indiv(i), p_pearsonLum_indiv(i),coords(i,:,:,:)] = rsa.MDSConditions_MEG2018_3D(RDMStruct,userOptionsColors, localOptionsAvg);
    saveName = [num2str(relativeTimes(MDS_inds(i))),'ms_MDS_3D.fig'];
    f = gcf;
    if toSave
        videoSaveName = ['MDS_3D_' num2str(relativeTimes(MDS_inds(i))),'ms_movie'];
        CaptureFigVid(ViewZ,[movieDir,videoSaveName],OptionZ);
        close(i)
    end
end

end
