% Plot term ID decoding accuracy
% Shridhar Singh

clearvars
close all

initializePaths

filename = 'term_decoding_results.mat';
load([quantitativeDataDir filename]);

%long window
bin_starts = linspace(-200,1195,280);
bin_widths = 5;
y_range = [0, .9];
chance = 0.5;

mean_acc = mean(outStruct.allIndivCurves);

meanAccBoot = sort(outStruct.bootDetails.timecourse.boot,2)+chance;
meanAccCI = [meanAccBoot(:,25), meanAccBoot(:,975)]';

CIDists = abs(mean_acc - meanAccCI)'; %if you want 95% CI shading
std_error = outStruct.avgSTDError; %if you want std error shading

figure
boundedline(bin_starts,mean_acc,std_error,'cmap',[0 0 0]);
hold on
for t = 1 : numel(outStruct.bootDetails.tndx_onsetOnwards)
    tI = outStruct.bootDetails.tndx_onsetOnwards(t);
    full_bin = bin_starts(tI) : bin_starts(tI) + bin_widths;
    line(full_bin,ones(size(full_bin))*(y_range(1) + 0.01),'linewidth',2,'Color',[0 0 0]);
end
xlim([-200, 1200])
ylim(y_range)
line(bin_starts, chance * ones(1, numel(bin_starts)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
set(gca,'fontsize',20);
grid off
box off

xlabel('Time (ms)', 'FontWeight', 'bold', 'FontSize', 18)
ylabel('Classification Accuracy (%)', 'FontWeight', 'bold', 'FontSize', 18)
title('Spiral Identity', 'FontSize', 18)

