%Figure 5: analysis on cross temporal generalization 
%Shridhar Singh 2020

%% load data
close all 
clearvars
decoding_result_type_name = 'Spiral ID';
initializePaths
filepath = [quantitativeDataDir 'XT_decoding_results_2ms_bins.mat'];
if ~exist(filepath,'file')
    [decodingAvgMat,conMat] = gather_spiralID_XT_runs();
else
    load(filepath)
end

%% define a frame for analysis
fullFrame = decodingAvgMat(101:400,101:400);
bin_size = 2;
preOnsetDuration = 200;
timeWindowY = [275,600];
timeWindowX = [0,600];
windowIndsY = (timeWindowY+200)/2;
windowIndsX = (timeWindowX+200)/2;
matFrame = decodingAvgMat(windowIndsY(1):windowIndsY(2),windowIndsX(1):windowIndsX(2));
frameSizeX = size(matFrame,2);
frameSizeY = size(matFrame,1);

%Show full cross temporal decoding with a box around the area defined above
figNum = 1;
plotAvgHeatMapNoSigCustom(fullFrame, 'Spiral ID', figNum,1,[0,40],2,0);
rectGunVal = 0.2;
rectColor = [rectGunVal,rectGunVal,rectGunVal];
hold on
xLine = linspace(timeWindowX(1)/2,timeWindowX(2)/2,diff(timeWindowX)/2+1);
yLine = linspace(timeWindowY(1)/2,timeWindowY(2)/2,diff(timeWindowY)/2+1);
line(xLine,ones(1,numel(xLine))*timeWindowY(1)/2,'Color',rectColor,'LineWidth',1.2)
line(xLine,ones(1,numel(xLine))*timeWindowY(2)/2-0.01,'Color',rectColor,'LineWidth',1.2)
line(ones(1,numel(yLine))*timeWindowX(1)/2+0.7,yLine,'Color',rectColor,'LineWidth',1.2)
line(ones(1,numel(yLine))*timeWindowX(2)/2,yLine,'Color',rectColor,'LineWidth',1.2)

figNum = 2;
plotAvgHeatMapNoSigCustom(matFrame, decoding_result_type_name,figNum,1,[0,40],2,0,200,316);
hold on
yticklabels({'275','300','325','350','375','400'})

%% Correlate the frame with shifted versions and get first and second derivatives 
rightShifted = zeros(frameSizeY,frameSizeX,frameSizeX+1);
rightShifted(:,:,1) = matFrame;
for i = 1:size(matFrame,2)
    rightShifted(:,:,i+1) = circshift(matFrame,i,2);
end

%get the correlation of the original to time shifted 
productsRight = zeros(frameSizeY,frameSizeX,frameSizeX+1);
corrsRight = zeros(1,frameSizeX+1);
for i = 1:size(matFrame,2)+1
   productsRight(:,:,i) = rightShifted(:,:,i) .* matFrame; 
   corrsRight(i) = corr2(rightShifted(:,:,i),matFrame);
end
allSums = corrsRight;

dSdt = diff(allSums);
d2Sdt2 = diff(dSdt);
dSdtHalf = dSdt(1:(frameSizeX-1)/2);
d2Sdt2Half = d2Sdt2(1:(frameSizeX-1)/2-1);

%% Plots to visualize the above
timeRange = timeWindowX(2) - timeWindowX(1);
frameSizeHalf = (frameSizeX-1)/2+1;
x = linspace(0,timeRange+bin_size,frameSizeX+1);

%view correlations versus shift size
figure
plot(x,allSums);
xlim([0, timeRange])
xticks(linspace(0,timeRange,timeRange/10+1))

%view derivative of correlation wrt to time shift
figure
x2 = linspace(0,timeRange,frameSizeX);
plot(x2,dSdt);
xlim([0, timeRange])
xticks(linspace(-timeWindowX(2),timeWindowX(2),timeWindowX(2)*2/50+1))

%view second derivative of correlation
figure
x3 = linspace(0,timeRange-bin_size,frameSizeX-1);
plot(x3,d2Sdt2);
xlim([0, timeRange])
xticks(linspace(0,timeWindowX(2),timeWindowX(2)/50+1))

%% fourier analysis

Fs = 500;
T = 1/Fs;
L = size(d2Sdt2Half,2)+2;
f = Fs*(0:(L/2))/L;

Y = fft(d2Sdt2Half);
P2 = abs(Y/L);
P1 = P2(1:L/2+1);
P1(2:end-1) = 2*P1(2:end-1);
figure(figNum+10)
plot(f,P1) 
title('Single-Sided Amplitude Spectrum d2Sdt2')
xlabel('f (Hz)')
ylabel('|P1(f)|')

[maxA,maxAind] = max(P1);
peakFreq = f(maxAind);

%% overlay a sine wave on second derivative plot for visualization

figure(12)
plot(x3,d2Sdt2,'Color',[0,0,0]);
hold on
xlim([0, timeRange])

t = 0:0.01:timeRange;

%parameters below obtianed by trial and error because the sine wave was just for 
%illustrative purposes
A = 0.0029;
phaseShift = 1.6;

S = A*sin(2*pi*peakFreq/1000*t + phaseShift*pi);

plot(t,S,'--','Color',[0,0,0])

%% shuffle d2Sdt2 to get amplitude spectrum of noise 
nBoot = 1000;
for i = 1:nBoot
    shuffleInds = randi(size(d2Sdt2Half,2),size(d2Sdt2Half,2),1);
    d2Sdt2Boot(:,i) = d2Sdt2Half(:,shuffleInds);
    Yd2Sdt2Boot(:,i) = fft(d2Sdt2Boot(:,i));
end
d2Sdt2BootMean = mean(d2Sdt2Boot,2);
%% on the bootstrapped fft
P2d2Sdt2Boot = abs(Yd2Sdt2Boot/L);
P1d2Sdt2Boot = P2d2Sdt2Boot(1:L/2+1,:);
P1d2Sdt2Boot(2:end-1,:) = 2*P1d2Sdt2Boot(2:end-1,:);
P1d2Sdt2Boot = sort(P1d2Sdt2Boot,2);

confidenceLevel = 0.95;

pSig = (1-confidenceLevel) / 2;
lowerCILevel = uint64(pSig*nBoot);
upperCILevel = nBoot - lowerCILevel;
P1d2Sdt2CI = [P1d2Sdt2Boot(:,lowerCILevel),P1d2Sdt2Boot(:,upperCILevel)];
P1d2Sdt2BootMean = mean(P1d2Sdt2Boot,2);
P1d2Sdt2CIDists = abs(P1d2Sdt2BootMean-P1d2Sdt2CI);

figure(11)
boundedline(f,P1d2Sdt2BootMean,P1d2Sdt2CIDists,'cmap',[0.35,0.35,0.35]) 
plot(f,P1d2Sdt2BootMean,'Color',[0.35,0.35,0.35],'LineWidth',1.2)
hold on
plot(f,P1,'Color',[0,0,0],'LineWidth',1.3) 
title('Single-Sided Amplitude Spectrum')
xlabel('f (Hz)')
ylabel('|P1(f)|')

%normalize powers to be relative to the peak for presentation purposes
P1_norm = P1 / max(P1);
P1d2Sdt2BootMean_norm = P1d2Sdt2BootMean / max(P1);
P1d2Sdt2Boot_norm = P1d2Sdt2Boot / max(P1);
P1d2Sdt2CI_norm = [P1d2Sdt2Boot_norm(:,lowerCILevel),P1d2Sdt2Boot_norm(:,upperCILevel)];
P1d2Sdt2CIDists_norm = abs(P1d2Sdt2BootMean_norm-P1d2Sdt2CI_norm);

figure(12)
boundedline(f,P1d2Sdt2BootMean_norm,P1d2Sdt2CIDists_norm,'cmap',[0.35,0.35,0.35]) 
plot(f,P1d2Sdt2BootMean_norm,'Color',[0.35,0.35,0.35],'LineWidth',1.5)
hold on
plot(f,P1_norm,'Color',[0,0,0],'LineWidth',2) 
title('Single-Sided Amplitude Spectrum')
xlabel('f (Hz)')
ylabel('Relative Power')

%% Where decoding is significantly above chance
nTimePts = size(conMat,2);
nBoot = 1000;
bootmean = bootstrp(nBoot,@mean,conMat);
chance = 0.125;
isBelowChance = bootmean < chance;
pMap = sum(isBelowChance,1) / nBoot;
[hFDR,~,~,pFDR] = fdr_bh(pMap,0.05);
pMap = reshape(pMap,nTimePts,nTimePts);
pFDR = reshape(pFDR,nTimePts,nTimePts);

figNum1 = 13;
isSig = pFDR < 0.05;
sigMap = zeros(size(pFDR));
sigMap(isSig) = 1;
plotAvgHeatMapNoSig(sigMap, 'SigMap', figNum1,[0,0.1],1)