%S1

clearvars
close all

initializePaths

problem = 'SpiralIdentity';
filename = [problem '_peak_adjusted_decoding_results.mat'];
filepath = [quantitativeDataDir filename];

if ~exist(filepath,'file')
    adjust_peaks(studyPath,problem)
end
load(filepath)

%% plot
chance = 0.125;

meanAcc = squeeze(mean(diagConMat,[1,2]))';
meanAccBoot = sort(onsetDataStruct.timecourse.boot,2)+0.125;
meanAccCI = [meanAccBoot(:,25), meanAccBoot(:,975)]';
CIDists = abs(meanAcc - meanAccCI);

f2 = figure('Color', [1 1 1]);
axes1 = axes('Parent', f2, 'FontSize', 16);

% plot standard error shading or 95% CI shading
boundedline(relativeTimes, meanAcc, CIDists', 'cmap',[0 0 0])
hold on
y_range = [0, .7]
ylim(y_range)
line(relativeTimes, chance * ones(1, numel(relativeTimes)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);

% line at stimulus onset
line(zeros(1, numel(y_range)), y_range, 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);
w1 = min(onsetDataStruct.mean);
w2 = max(onsetDataStruct.mean);
w = w2 + 0.1*(w2-w1);
Line.x = relativeTimes(onsetDataStruct.tndx_onsetOnwards-1);
% Line.y = w * ones(size(Line.x))
Line.y = ones(size(Line.x)) * (y_range(1) + 0.05);
plot(Line.x,Line.y,'k','linewidth',2);
set(gca,'fontsize',20);
grid off
box off

xlabel('Time (ms)', 'FontWeight', 'bold', 'FontSize', 18)
ylabel('Classification Accuracy (%)', 'FontWeight', 'bold', 'FontSize', 18)
title('Spiral Identity', 'FontSize', 18)


%% plot all colors
colorMat = [0.9803921568627451, 0.7843137254901961, 0.9490196078431372;... % az45 elev20
    0.8666666666666667, 0.6078431372549019, 0.8274509803921568;... %    elev340
    0.7333333333333333, 0.8352941176470589, 0.9490196078431372;... %az135
    0.5294117647058824, 0.6823529411764706, 0.8313725490196079;...
    0.6313725490196078, 0.8784313725490196, 0.6862745098039216;... %az225
    0.3137254901960784, 0.7372549019607844, 0.44313725490196076;...
    0.9176470588235294, 0.8274509803921568, 0.6823529411764706;... %az315
    0.792156862745098, 0.6705882352941176, 0.4392156862745098];

colorMeans = squeeze(mean(diagConMat,2));

bin_widths = 5;
colorOrder = [3,4,5,6,7,8,2,1];

figure
for i = colorOrder
   plot(relativeTimes,onsetDataStruct_Diag(i).mean+chance,'Color',colorMat(i,:),'LineWidth',3);
   hold on
   for t = 1 : numel(onsetDataStruct_Diag(i).tndx_onsetOnwards)
       tI = onsetDataStruct_Diag(i).tndx_onsetOnwards(t)-1;
       full_bin = relativeTimes(tI) : relativeTimes(tI) + bin_widths;
       line(full_bin,ones(size(full_bin))*(y_range(1) + 0.01*i),'linewidth',2,'Color',colorMat(i,:));
   end
end

ylim(y_range)
line(relativeTimes, chance * ones(1, numel(relativeTimes)), 'LineWidth', 2, 'Color', [0.6 0.6 0.6]);

% line at stimulus onset
set(gca,'fontsize',20);
grid off
box off

xlabel('Time (ms)', 'FontWeight', 'bold', 'FontSize', 18)
ylabel('Classification Accuracy (%)', 'FontWeight', 'bold', 'FontSize', 18)
title('Spiral Identity Peak Adjusted Time', 'FontSize', 18)
