% Adjust timing of each subject's decoding time course to be relative to
% the time to peak decoding accuracy (time to peak corresponds to 0 ms)

function adjust_peaks(problem)

initializePaths;

probCond = [problem '_' condition];

outStruct_name = 'SpiralIdentity_decoding_results.mat';
load([quantitativeDataDir outStruct_name],'outStruct');

subjs = {'lilac04', 'lilac05','lilac06', 'lilac07','lilac10','lilac12',...
    'lilac13', 'lilac14','lilac15',  'lilac16',  'lilac17', 'lilac18',...
    'lilac19', 'lilac20', 'lilac21', 'lilac22', 'lilac23', 'lilac24'};
nSubjs = numel(subjs);

% all subject time points are relative to their peak
bin_width = 5;
firstTime = -200;
lastTime = 595;
num_bins = (lastTime-firstTime+bin_width)/bin_width;
bin_starts = linspace(firstTime,lastTime,num_bins);

offsetTime = outStruct.offsetTime;
offsetInd = find(bin_starts==offsetTime);
subjectPeakTimes = outStruct.allIndivPeakTimes;

%for any peak that occurs after the offset, adjust it to be the highest
%local maximum before the offset time
latePeakSubjs = find(subjectPeakTimes >= offsetTime);
for i = 1:numel(latePeakSubjs)
    localMaxima = islocalmax(outStruct.allIndivCurves(latePeakSubjs(i),1:offsetInd-1));
    localMaxI = find(localMaxima==1);
    localMaxValue = outStruct.allIndivCurves(latePeakSubjs(i),localMaxima);
    [~,peakI] = max(localMaxValue);
    peakI = localMaxI(peakI);
    subjectPeakTimes(latePeakSubjs(i)) = bin_starts(peakI);
end
firstPeak = min(subjectPeakTimes);
lastPeak = max(subjectPeakTimes);

nBinsBeforePeak = (firstPeak - firstTime) / bin_width;
nBinsAfterPeak = (lastTime - lastPeak) / bin_width;

timesBeforePeak = zeros(nSubjs,nBinsBeforePeak);
for i = 1:size(timesBeforePeak,1)
    startTime = subjectPeakTimes(i) - nBinsBeforePeak*bin_width;
    timesBeforePeak(i,:) = linspace(startTime,subjectPeakTimes(i)-bin_width,nBinsBeforePeak);
end
relativeTimeBeforePeak = linspace(-(nBinsBeforePeak*bin_width),-bin_width,nBinsBeforePeak);
timesAfterPeak = zeros(nSubjs,nBinsAfterPeak+1);
for i = 1:size(timesAfterPeak,1)
    endTime = subjectPeakTimes(i) + nBinsAfterPeak*bin_width;
    timesAfterPeak(i,:) = linspace(subjectPeakTimes(i),endTime,nBinsAfterPeak+1);
end
relativeTimeAfterPeak = linspace(0,nBinsAfterPeak*bin_width,nBinsAfterPeak+1);
times = cat(2,timesBeforePeak,timesAfterPeak);
relativeTimes = cat(2,relativeTimeBeforePeak,relativeTimeAfterPeak);

[meanConMats, meanConMatStds, diagConMat, allConMats]= getNormalizedConfusionMatrices(subjs, times, probCond);

svname = [problem '_peak_adjusted_decoding_results.mat'];
savepath = [quantitativeDataDir svname];

if strcmp(problem,'SpiralIdentityForcedError')
    save(savepath,'meanConMats','meanConMatStds','diagConMat','allConMats',...
        'relativeTimes','times');
else
    mean_acc_allSubj = squeeze(mean(diagConMat));
    chance = 0.125;
    data = mean_acc_allSubj - chance;
    tail = 'right';
    nboot = 1000;
    nperm = 1000;
    significance_th = 0.05;
    [onsetDataStruct] = onset_peak_bootstrap_FDR_significance(data,relativeTimes,nboot,nperm,significance_th,tail);
    onsetDataStruct.times = relativeTimes;

    for i = 1:size(diagConMat,1)
        thisAcc = squeeze(diagConMat(i,:,:));
        data = thisAcc - chance;
        tail = 'right';
        nboot = 1000;
        nperm = 1000;
        significance_th = 0.05;
        [onsetDataStruct_Diag(i)] = onset_peak_bootstrap_FDR_significance(data,relativeTimes,...
            nboot,nperm,significance_th,tail);
    end

    %gather the bootstrap information for easy access
    diagConMatBoot = zeros(size(diagConMat,1),nboot,size(diagConMat,3));
    for i = 1:size(diagConMat,1)
        diagConMatBoot(i,:,:) = onsetDataStruct_Diag(i).timecourse.boot';
    end
    diagConMatBootSort = sort(diagConMatBoot,2);
    diagConMatCI = cat(2,diagConMatBootSort(:,25,:),diagConMatBootSort(:,975,:));

    save(savepath,'meanConMats','meanConMatStds','diagConMat','allConMats',...
        'relativeTimes','times','onsetDataStruct','onsetDataStruct_Diag',...
       'diagConMatBoot','diagConMatCI');
end
end