% Gather the decoding results for all subjects for color term
% decoding from the neural decoding toolbox outputs and save them in one 
% place
% Shridhar Singh

clearvars
close all

initializePaths;
resultsBase = [studyPath 'Intermediates_Study/MaxCorr/Results_LongWindow/'];

condition = 'HueCond';
problem = 'TermIdentity';
probCond = [problem '_' condition];
savePath = quantitativeDataDir;
if ~exist(savePath)
    mkdir(savePath)
end

bin_size = 5;
totalTime = 1400;
num_bins = totalTime / bin_size;
bin_starts = linspace(-200,1195,num_bins);

%for bootstrapping peak and for onset latency
nperm = 1000;
nboot = 1000;
significance_th = 0.05;

subjIDs = {'lilac04_CombinedSess_01_02',...
    'lilac05_CombinedSess_01_02', ... 
    'lilac06_CombinedSess_01_02', ... 
    'lilac07_CombinedSess_01_02', ...
    'lilac10_CombinedSess_01_02',... 
    'lilac12_CombinedSess_01_02',...
    'lilac13_CombinedSess_01_02',...    
    'lilac14_CombinedSess_01_02', ...
    'lilac15_CombinedSess_01_02',...
    'lilac16_CombinedSess_01_02',...
    'lilac17_CombinedSess_01_02',...
    'lilac18_CombinedSess_01_02',...   
    'lilac19_CombinedSess_01_02',...
    'lilac20_CombinedSess_01_02',...
    'lilac21_CombinedSess_01_02',...
    'lilac22_CombinedSess_01_02', ... 
    'lilac23_CombinedSess_01_02', ... 
    'lilac24_CombinedSess_01_02'};

acc = zeros(numel(subjIDs),num_bins);

for s = 1 : numel(subjIDs)
    subj = subjIDs{s}
    results_root = [resultsBase subj '/'];        
    filename = [subj '_' probCond '_' params_desc '.mat'];
    real_decoding_results_file_name  = [results_root probCond '/' filename];
    load(real_decoding_results_file_name);
    
    mean_decoding_results = DECODING_RESULTS.ZERO_ONE_LOSS_RESULTS.mean_decoding_results;
    
    %size is different if decoding was cross temporal. Don't care about
    %cross temporal decoding here, so just get diagonal
    if size(mean_decoding_results,1) == size(mean_decoding_results,2)
        acc(s, :) = diag(DECODING_RESULTS.ZERO_ONE_LOSS_RESULTS.mean_decoding_results)';
    else
        acc(s, :) = DECODING_RESULTS.ZERO_ONE_LOSS_RESULTS.mean_decoding_results';
    end
    
    %look at decoding peaks
    [outStruct.IndivPeakVals(s), peaksInds_bySubj(s)] = max(acc(s, :));
    peaks_bySubj(s) = bin_starts(peaksInds_bySubj(s));
    outStruct.name(s) = subjIDs(s);
    
    %look at SNR
    baselineInds = 1 : 200/bin_size; 
    baselineAcc  = acc(s,baselineInds);
    outStruct.IndivMeanBaselineAcc(s) = mean(baselineAcc);
    outStruct.IndivSNR(s) = outStruct.IndivPeakVals(s)/std(baselineAcc);
end

% peak of the mean decoding
mean_acc = mean(acc);
[peak_val, peak_ind] = max(mean_acc);
peak_time = bin_starts(peak_ind);

% SNR of the mean decoding
baselineInds = 1 : 40;
baselineAcc  = mean_acc(baselineInds);
outStruct.avgSNR = peak_val/std(baselineAcc);

% standard error across subjects
n = size(acc, 1);
std_err = std(acc)/sqrt(n);

% determine onset for mean decoding
chance = 1/(DECODING_RESULTS.CV_PARAMETERS.num_unique_labels);
data= acc - chance;
tail = 'right';
onsetDataStruct = onset_peak_bootstrap_FDR_significance(data,bin_starts,nboot,nperm,significance_th,tail);
onset = onsetDataStruct.onset.orig;

%prepare a structure with detailed info for save
outStruct.params_desc = params_desc;
outStruct.problem = problem;
outStruct.avgOnset = onset;
outStruct.bootDetails = onsetDataStruct;
if ~isempty(onset)
    disp('95% CI for onset:')
    onsetDataStruct.onset.confidence95
end
outStruct.avgPeakTime = peak_time;
outStruct.allIndivCurves = acc;
outStruct.allIndivPeakTimes = peaks_bySubj;
outStruct.maxAvgPeak = peak_val;
outStruct.maxAvgPeak95 = onsetDataStruct.peakValue.confidence95 + chance;
outStruct.meanBaselineAcc = mean(outStruct.IndivMeanBaselineAcc);
outStruct.avgSTDError = std_err;

svname = [savePath 'term_decoding_results.mat'];
save(svname,'outStruct')
