# Takes path and combines csv files within that directory

import json
import csv
import os
import ast
import numpy as np
import matplotlib
import matplotlib.pyplot as plt
import matplotlib.font_manager as fm
import random
import collections
import operator
from scipy.io import savemat

# make sure to end pathnames with '/'
rootPath = 'T:/users/singhsr/MEG_Project2018/mTurk/Experiment2/data_processing/'
processedData = rootPath + 'processed_results/processed_results.csv'
savePath = 'T:/users/singhsr/MEG_Project2018/Geometry/Quantitative_Data/';

#Dictionary that corrects mispellings of words, so as to accuratley count
#how many unique terms were used
mispellDict = {'fuschia':'fuchsia', 'fushia':'fuchsia', 'fuchia':'fuchsia', 'fushcia':'fuchsia', 'fuscia':'fuchsia',
               'lavendar':'lavender',
               'grey':'gray',
               'turqoise':'turquoise','turquois':'turquoise','turquiose':'turquoise', 'turqouise':'turquoise',
               'baige':'beige', 'biege':'beige',
               'prange':'orange',
               'oink':'pink', 'pin':'pink', '[ink':'pink',
               'purplr':'purple', 'pruple':'purple', 'puple':'purple',
               'perwinkle':'periwinkle', 'perewinkle': 'periwinkle',
               'megenta':'magenta', 'mejenta':'magenta',
               'zerulean':'cerulean',
               'greeen':'green', 'breen':'green', 'greeb':'green',
               'charturse':'chartruese', 'chartreuse':'chartruese', 'chartruse':'chartruese', 'chartreusse':'chartruese',
               'avacada':'avocada',
               'brwn':'brown',
               'mynt':'mint',
               'glod':'gold',
               'lylac':'lilac',
               'meron':'maroon'}

def wrapper(dataPath):
        # Read in data
        allDicts = csvToDicts(dataPath) # convert rows to dictionaries
        # Pull relevant fields
        spiralNames = ['spiral_az45sat75elev20', 'spiral_az45sat75elev340', 
                                        'spiral_az135sat75elev20', 'spiral_az135sat75elev340', 
                                        'spiral_az225sat75elev20', 'spiral_az225sat75elev340', 
                                        'spiral_az315sat75elev20', 'spiral_az315sat75elev340']
        spiralRGBs = createColorDict()


        
        termsUsedAcross = acrossSubjects(allDicts, spiralNames)

        indivCount = countSameUse(allDicts, spiralNames, termsUsedAcross, spiralRGBs)

        #countWithinStimConcordance(allDicts, spiralNames, termsUsedAcross, spiralRGBs)
        
        return indivCount

#for each subject count the number of times they repeated the same word for low and high lum
def countSameUse(dicts, spiralNames, termsAcross, spiralRGBs):
        spiralPairs = [[0,1], [2,3], [4,5], [6,7]]
        jnd = 0
        #indivCount is for each subject 1 if they repeated, 0 if not for each spiral
        indivCount = [[] for i in range(len(spiralPairs))]
        matchTerm = [[] for i in range(len(spiralPairs))]
        counts = []
        name = ['az45', 'az135', 'az225','az315']
        for k in range(len(spiralPairs)): #for each spiral pair
                termsLowLum = termsAcross[spiralNames[spiralPairs[k][0]]]
                termsHighLum = termsAcross[spiralNames[spiralPairs[k][1]]]
                termsLowLum = fixSpelling(termsLowLum) #this holds all subjects terms
                termsHighLum = fixSpelling(termsHighLum) #this holds all subjects terms
     
                ind = 0;
                for u in termsLowLum: #for each subject's responses
                                if u == termsHighLum[ind]:
                                        indivCount[jnd].append(1)
                                        matchTerm[jnd].append(u)
                                else:
                                        indivCount[jnd].append(0)
                                ind = ind + 1
                counts.append(average(indivCount[jnd]))
                
                #return counts which for each spiral is percent of subj repeated
                jnd = jnd +1
        return indivCount
        
def createColorDict():

        rgbsDict = {}

        # brights
        rgbsDict['spiral_az0sat75elev20']    = [253,    203,    212]
        rgbsDict['spiral_az45sat75elev20']   = [250,    200,    242]
        rgbsDict['spiral_az90sat75elev20']   = [225,    204,    253]
        rgbsDict['spiral_az135sat75elev20']  = [187,    213,    242]
        rgbsDict['spiral_az180sat75elev20']  = [154,    221,    213]
        rgbsDict['spiral_az225sat75elev20']  = [161,    224,    175]
        rgbsDict['spiral_az270sat75elev20']  = [198,    220,    154]
        rgbsDict['spiral_az315sat75elev20']  = [234,    211,    174]

        # darks
        rgbsDict['spiral_az0sat75elev340']   = [225,    159,    172]
        rgbsDict['spiral_az45sat75elev340']  = [221,    155,    211]
        rgbsDict['spiral_az90sat75elev340']  = [191,    162,    225]
        rgbsDict['spiral_az135sat75elev340'] = [135,    174,    212]
        rgbsDict['spiral_az180sat75elev340'] = [55,             184,    173]
        rgbsDict['spiral_az225sat75elev340'] = [80,             188,    113]
        rgbsDict['spiral_az270sat75elev340'] = [153,    183,    55]
        rgbsDict['spiral_az315sat75elev340'] = [202,    171,    112]

        return rgbsDict

def fixSpelling(lst):
        terms = lst[:]
        for i,t in enumerate(terms):
                if t in list(mispellDict.keys()):
                        terms[i] = mispellDict[t]
        return terms
                        

def acrossSubjects(dicts, spiralNames):
        termsUsedAcross = {}
        for spiral in spiralNames:
                termsUsedAcross[spiral] = list()

        for d in dicts:
                for spiral in spiralNames:
                        # convert '[list]' to [list] (result of our csv read in)
                        termsList = ast.literal_eval(d[spiral])
                        termsList = fixSpelling(termsList)
                        
                        # randomly select 1 response
                        random.shuffle(termsList)
                        use = termsList[0]
                        termsUsedAcross[spiral].append(use)

        return termsUsedAcross

# read csv file to python dictionary
def csvToDicts(fname):
        dicts = []
        with open(fname, 'U') as csvfile:
                reader=csv.DictReader(csvfile)
                for row in reader:
                        dicts.append(row)
        #print len(dicts)
        return dicts

def average(lst):
        total = 0.0
        for n in lst:
                total+=n
        return total/len(lst)

indivCount = wrapper(processedData)
returnDict = {'concordMat':indivCount}
savemat(savePath + 'mTurkConcord.mat',returnDict)