
# Takes path and combines csv files within that directory

import json
import csv
import os
import ast

# make sure to end path names with '/'
rootPath = 'T:/users/singhsr/MEG_Project2018/mTurk/Experiment2/data_processing/'
sourcePathName   = rootPath + 'raw_results/'
analyzeSaveName  = rootPath + 'processed_results/processed_results.csv'
rejectsSaveName  = rootPath + 'processed_results/auto_rejected.csv'
incompletesSaveName = rootPath + 'processed_results/incompletes_rejected.csv'

def wrapper(path, analyzeName, rejectsName, incompletesName):
	processedDicts = []
	rejects  = []
	incompleteSubjects = []
	dirs = os.listdir(path)
	dirs = [d for d in dirs if (d.endswith('.csv'))] # in case we have multiple results files
	print (dirs)
	for file in dirs:
		tempDicts = csvToDicts(path + file) # convert rows to dictionaries
		for d in tempDicts: 
			print('***** SUBJ *******')

			# initialize new dictionary
			analyzeDict = {}
			targetKeys = generateTargetFieldNames()
			for t in targetKeys:
				analyzeDict[t] = list()

			# carry over vals
			for k in d.keys():
				if k != 'datastring':
					analyzeDict[k] = d[k]
				else:
					temp = d['datastring']
					if len(temp) == 0 or temp == '"NULL"':
						analyzeDict[k] = d[k] # Null val
						reject = 1
						reason = 'Incomplete'
					else:
						analyzeDict, reject, reason = reformatData(analyzeDict, temp)
						# check rejection criteria
						if reject == 0:
							reject, reason = checkExclusionCriteria(reject, analyzeDict)

			# append to appropriate csv
			if reject == 1:
				if reason is 'Incomplete':
					incompleteSubjects.append(d)
				else:
					analyzeDict['RejectionReason'] = reason
					rejects.append(analyzeDict)
			elif reject == 0:
				processedDicts.append(analyzeDict)

	# write back to csv filetype
	dictsToCSV(processedDicts, analyzeName)
	dictsToCSV(rejects, rejectsName)
	dictsToCSV(incompleteSubjects, incompletesName)

def reformatData(d, temp):
	reject = 0
	reason = ''

	# turn this field into a dictionary
	temp = temp.replace('null', '"null"')
	temp = temp.replace('[]', '""')
	if temp[0] == '"': temp = temp[1:-1]
	temp = ast.literal_eval(temp)
	temp = flattenDict(temp)

	for k in temp.keys():
		sp = k.split('_')

		# Grid questions, e.g. BLUE_BrightGrid_stim15
		if ('BrightGrid' in sp) | ('DarkGrid' in sp) | ('EquilumGrid' in sp):
			newKeyName = sp[0] + '_' + sp[1]
			d[newKeyName].append(temp[k])
		
		# Spiral questions, e.g. spiral_az0sat75elev340_stim19
		elif 'spiral' in sp:
			newKeyName = sp[0] + '_' + sp[1]
			if len(temp[k].split()) > 1 or '-' in temp[k]:
				print('Rejecting...')
				print(temp[k])
				reject = 1
				reason = 'TooManyWords'
			temp[k] = temp[k].replace('\n', '')
			temp[k] = temp[k].replace(' ', '')
			d[newKeyName].append(temp[k].lower()) # add words as all lower case

		# Attention questions, e.g. attentionPair_3stimuli_6
		elif ('attentionPair' in sp):
			if ('rawData' not in sp):
				newKeyName = 'AttentionPair'
				d[newKeyName].append(temp[k])
		
		# Other question types
		else:
			d[k] = temp[k]

	return d, reject, reason 


def checkExclusionCriteria(reject, d):
	# Check rejection criteria
	while 1:
		if d['workerId'] is 'A173CZB3T6Z4GV':
			reject = 1
			reason = 'Manual'
			return reject, reason

		if d['colorblind'] != 'no':
			reject = 1
			reason = 'Colorblind'
			return reject, reason

		if d['firstLanguage'] != 'English':
			reject = 1
			reason = 'FirstLanguageNotEnglish'
			return reject, reason

		incorrect = 0
		attentionCheck = d['AttentionPair']
		for i in attentionCheck:
			if i == 'incorrect':
				incorrect = incorrect + 1
		if incorrect > 2:
			reject = 1
			reason = 'AttentionChecks'
			return reject, reason

		reason = ''
		return reject, reason

# flatten dictionary
def flattenDict(d):
	dFlat = d.copy()
	for key in d.keys():
		if type(d[key]) is dict:
			content = d[key]
			del dFlat[key]
			for el in content.keys():
				dFlat[el] = content[el]
	return dFlat

# pull all keys
def pullUniqueKeys(listOfDicts):
	uniqueKeys = []
	for d in listOfDicts:
		for k in d.keys():
			if not(k in uniqueKeys):
				uniqueKeys.append(k)
	uniqueKeys = sorted(uniqueKeys)
	return uniqueKeys

# write dictionary back to csv file
def dictsToCSV(ds, fname):
	with open(fname, 'w') as csvfile:
		#fieldnames = ds[0].keys()
		fieldnames = pullUniqueKeys(ds)
		#fieldnames=ds[0].keys() # CHECK -- fieldsnames shoudl be the header of 1st row
		writer=csv.DictWriter(csvfile, fieldnames=fieldnames)
		writer.writeheader()
		for d in ds:
			writer.writerow(d)

# read csv file to python dictionary
def csvToDicts(fname):
	dicts = []
	with open(fname) as csvfile:
		reader=csv.DictReader(csvfile)
		for row in reader:
			dicts.append(row)
	#print len(dicts)
	return dicts

def generateTargetFieldNames():
	# spiral questions
	spiralNames = ['spiral_az0sat75elev20', 'spiral_az0sat75elev340',
	 				'spiral_az135sat75elev20', 'spiral_az135sat75elev340',
	 				'spiral_az180sat75elev20', 'spiral_az180sat75elev340', 
	 				'spiral_az225sat75elev20', 'spiral_az225sat75elev340', 
	 				'spiral_az270sat75elev20', 'spiral_az270sat75elev340',
	 				'spiral_az315sat75elev20', 'spiral_az315sat75elev340', 
	 				'spiral_az45sat75elev20', 'spiral_az45sat75elev340', 
	 				'spiral_az90sat75elev20', 'spiral_az90sat75elev340']

	# grid questions
	colorTerms = ['GREEN', 'YELLOW', 'ORANGE', 'BLUE', 'PURPLE', 'PINK']
	gridPrefixes = ['BrightGrid', 'DarkGrid', 'EquilumGrid']

	# assemble unique field names
	uniqueFieldNames = spiralNames
	for term in colorTerms:
		for grid in gridPrefixes:
			uniqueFieldNames.append(term + '_' + grid)

	# TODO: Add attention check questions (correct, not raw)
	uniqueFieldNames.append('AttentionPair')

	return uniqueFieldNames


wrapper(sourcePathName, analyzeSaveName, rejectsSaveName, incompletesSaveName)
print('Time to handprocess!!!')
