%%plot light vs dark color accuracy w/error bars
clear all
close all

%load in the values
initializePaths;

nSubjs = 18;
problem = 'SpiralIdentity';

classifier = 'MaxCorr';
params_desc = '25sensors_75avg_5splits_75repsPerSplit';

filename = [problem '_peak_adjusted_decoding_results.mat']; 
filepath = [quantitativeDataDir filename];

if ~exist(filepath)
    adjust_peaks(problem);
end
load(filepath);

%get the data that corresponds to the peak
peakI = find(relativeTimes==0);
meanConMats = meanConMats(:,:,peakI);
meanConMatStds = meanConMatStds(:,:,peakI);
diagConMat = diagConMat(:,:,peakI);
allConMats = allConMats(:,:,:,peakI);

%pull out values for each hue averaged across luminances
az45 = mean(diagConMat(1:2,:));
az135 = mean(diagConMat(3:4,:));
az225 = mean(diagConMat(5:6,:));
az315 = mean(diagConMat(7:8,:));

elev20 = mean(diagConMat([1,3,5,7],:));
elev340 = mean(diagConMat([2,4,6,8],:));

%% ANOVAS
JASP_table = diagConMat';
diagConMat1D = diagConMat';
diagConMat1D = reshape(diagConMat1D,[],1);
diagConMat1DRank = tiedrank(diagConMat1D);
% diagConMatRank = tiedrank(diagConMat);
diagConMatRank = reshape(diagConMat1DRank,8,18);

varNames = {'Lp','Dp','Lb','Db','Lg','Dg','Lo','Do'};
dataTable = array2table(diagConMat','VariableNames',varNames);
rankDataTable = array2table(diagConMatRank','VariableNames',varNames);

lumLevel = {'L','D','L','D','L','D','L','D'}';
hues = {'P','P','B','B','G','G','O','O'}';
warmCool = {'Warm','Warm','Cool','Cool','Cool','Cool','Warm','Warm'}'; %P,O and B,G
cones = {'+S','+S','+S','+S','-S','-S','-S','-S'}'; %P,B and G,O
axes = {'ADL','ADL','DL','DL','ADL','ADL','DL','DL'}'; %P,G and B,O

factorNames = {'Luminance','Hue','Warmth','SCone','Daylight'};
within = table(lumLevel,hues,warmCool,cones,axes,'VariableNames',factorNames);

rm = fitrm(dataTable,'Lp-Do~1','WithinDesign',within);
rmRank = fitrm(rankDataTable,'Lp-Do~1','WithinDesign',within);

% how does classification accuracy vary by hue and luminance
disp('ANOVA on classification accuracy by hue and luminance') 
hueFactor = repmat([1,2,3,4],36,1);
hueFactor = reshape(hueFactor,[],1);
lumFactor = repmat([1,2],18,4);
lumFactor = reshape(lumFactor,[],1);

disp('On the regular data')
rm_anova2(diagConMat1D, subjectGrouping, hueFactor, lumFactor, {'hue','lum'})
disp('On tied rank data')
rm_anova2(diagConMat1DRank, subjectGrouping, hueFactor, lumFactor, {'hue','lum'})
disp('Using fitrm')
ranova(rm,'WithinModel','Luminance*Hue')
ranova(rm,'WithinModel','Luminance')

% how does classification accuracy vary by hue warmth and luminance
warmCoolFactor = ([ones(1,nSubjs)*1, ones(1,nSubjs)*1, ones(1,nSubjs)*2, ones(1,nSubjs)*2,...
    ones(1,nSubjs)*2, ones(1,nSubjs)*2, ones(1,nSubjs)*1, ones(1,nSubjs)*1])';
lumFactor = repmat([1,2],18,4);
lumFactor = reshape(lumFactor,[],1);

disp('ANOVA on classification accuracy by hue warmth and luminance')
disp('On the regular data')
rm_anova2(diagConMat1D, subjectGrouping, warmCoolFactor, lumFactor, {'warm/cool','lum'})
disp('On tied rank data')
rm_anova2(diagConMat1DRank, subjectGrouping, warmCoolFactor, lumFactor, {'warm/cool','lum'})
disp('Using fitrm')
ranova(rm,'WithinModel','Luminance*Warmth')

% S-cone axis 
disp('ANOVA on classification accuracy by plus or minus S-cone')
coneFactor = repmat([1,2],18*4,1);
coneFactor = reshape(coneFactor,[],1);

disp('One way ANOVA')
ranova(rm,'WithinModel','SCone')
disp('Two way ANOVA with luminance')
rm_anova2(diagConMat1DRank, subjectGrouping, coneFactor, lumFactor, {'+S/-S','lum'})

% Daylight axis
disp('ANOVA on classification accuracy of daylight versus antidaylight colors')
axisFactor = ([ones(1,nSubjs)*2, ones(1,nSubjs)*2, ones(1,nSubjs)*1, ones(1,nSubjs)*1,...
    ones(1,nSubjs)*2, ones(1,nSubjs)*2, ones(1,nSubjs)*1, ones(1,nSubjs)*1])';

disp('Two way ANOVA with luminance')
rm_anova2(diagConMat1DRank, subjectGrouping, axisFactor, lumFactor, {'DL/ADL','lum'})
ranova(rm,'WithinModel','Daylight*Luminance')

hueFactor = repmat([1,2,3,4],36,1);
hueFactor = reshape(hueFactor,[],1);
lumFactor = repmat([1,2],18,4);
lumFactor = reshape(lumFactor,[],1);
subjNum = repmat(1:18,1,8);
subjNum = subjNum';
JASP_table = cell(144,7);
JASP_table(:,1) = num2cell(subjNum);
JASP_table(:,2) = num2cell(lumFactor);
JASP_table(:,3) = num2cell(hueFactor);
JASP_table(:,4) = num2cell(axisFactor);
JASP_table(:,5) = num2cell(warmCoolFactor);
JASP_table(:,6) = num2cell(coneFactor);
JASP_table(:,7) = num2cell(diagConMat1D);


subjData = repmat(subjectNames,8,1);
JASP_table = {subjData,lumFactor,hueFactor,axisFactor,warmCoolFactor,coneFactor};

%% t-tests
%do t-tests on average performance across axes
%across S axis (pink/blue vs orange/green)
[~, p_acrossSaxis] =ttest(mean([az45; az135]),mean([az225; az315])) 
p_acrossSaxis =signrank(mean([az45; az135]),mean([az225; az315])) 

%across L-M axis (pink/orange vs blue/green)
[~, p_acrossLminusMaxis] =ttest(mean([az45; az315]),mean([az135; az225])) 
p_acrossLminusMaxis =signrank(mean([az45; az315]),mean([az135; az225])) 
p_acrossLminusMaxis =signrank([az45, az315],[az135, az225]) 


%blue/orange vs pink/green
[~, p_dayLight] =ttest(mean([az135; az315]),mean([az45; az225])) 
p_dayLight =signrank(mean([az135; az315]),mean([az45; az225])) 

%across lightness levels
p_lightness = signrank(elev20,elev340)

%structure to save to csv for JASP for bayes factors 
plusS = mean([az45; az135]);
minusS = mean([az225; az315]);

plusLminusM = mean([az45; az315]);
minusLminusM = mean([az135; az225]);

daylight = mean([az135; az315]);
antiDaylight = mean([az45; az225]);

light = mean(diagConMat([1,3,5,7],:));
dark = mean(diagConMat([2,4,6,8],:));

% for doing bayesian statistics in JASP
forJasp = [plusS;minusS;plusLminusM;minusLminusM;daylight;antiDaylight;light;dark]';
forJasp = [az45,az135; az225,az315; az45, az315; az135, az225; az135, az315; az45, az225]'; 