## Decoding Overview

### Overview

This directory contains the code needed to run the decoding analysis and to produce the figures Rosenthal et. al, 2020 (Curr Biol.). The decoding scripts are in the directory `Decoding`, and the scripts to produce figures are in `Geometry`.

This guide is an overview of how to run the decoding analysis. More information on how to run specific decoding problems are in geometry_analysis_guide.md.

There are also several empty directories. These directories are populated by the decoding scripts, but including all the files would have increased the overall size too much. Instead, some of these files are available for download from neicommons (https://neicommons.nei.nih.gov/#/MEGco), and others must be reproduced by running the scripts.

#### Raw data
The raw MEG data in BIDS format can be accessed on [openneuro](https://openneuro.org/datasets/ds003352/versions/1.0.0).

#### Preprocessed data
Many of the intermediate data files are located on the neicommons page. The following is a description of these files.

The raw MEG data was preprocessed using Brainstorm to remove eye blink artifacts and trials in which any sensor exhibited out-of-range activity (0.1-8000 fT). The brainstorm preprocessed MEG data is available on neicommons. Due to the large directory sizes, there is one zipped directory for each session of each subject. The decoding analysis was initially done on trials epoched with a window of [-200,600] ms. Later, for the color terms decoding, the window was expanded to [-200,1200] ms. Therefore, there are two sets of preprocessed data for each subject-session in the main experiment (as opposed to the pilot experiments).

**Intermediates_Data** contains the preprocessed data for the main experiment. There are two sessions for each of 18 subjects. For the decoding code to run as written, these data should be put in `/MEG_Project2018/Intermediates_Data/data/`. If you put it somewhere else, then you must edit the code to reflect the change in paths.

**anat.zip** contains the anatomical ROI's in Brainstorm for 14 subjects. These correspond to the data in Intermediates_Data. The files within anat.zip should be saved in `/MEG_Project2018/Intermediates_Data/anat/`

**Intermediates_Data_LongWindow** contains the preprocessed data for the main experiment with the expanded time window. These data should be put in `/MEG_Project2018/Intermediates_Data_LongWindow/data/`.

**Task Control Experiment** contains the preprocessed data for the second pilot experiment with the task control. There are two subjects with 5 sessions each. These data should be put in `/MEG_Project2018/Intermediates_Data/data/`.

**Pilot0** contains the preprocessed data for the initial pilot experiment. There are 4 subjects with 1 session each. These data should put in `/MEG_Project2018/Pilot0/Brainstorm_Format/`.

#### Raster Format
The preprocessed data was converted to a raster format for the decoding analysis. The raster data for a given subject consists of 306 `.mat` files (one for each MEG channel) containing data for all the trials and a separate structure that denotes the stimulus that appeared during each trial.

Raster data for the main experiment with the shorter time window is available on neicommons. The two sessions were combined for each subject into one set of raster files, so there are 18 zipped directories with raster data. This raster data should be stored in `MEG_Project2018/Intermediates_Study/Raster_Format/`

Raster files for the longer window and for the pilots are not included but can be produced by scripts which will be described later.

### Decoding Analysis

The code for decoding from MEG data is located in the directory `/MEG_Project2018/Decoding/`, so that is the base directory for everything in this section. All the decoding scripts were run on a cluster computer because of long run times.

Decoding was done using the neural decoding toolbox. We customized some of the scripts, so the edited version of the toolbox is in `/MEG_Project2018/toolbox/ndt.1.0.4_exported`.

#### Converting to Raster Format

The scripts to rasterize the Brainstorm data are in `/PreprocessingCode/` (for the first pilot they are in `/Pilot0/PreprocessingCode/`). The only raster format files provided here are the MEG data from the main experiment with the shorter time window. For ROI's, long window, and pilots, the preprocessing scripts must be run.

`wrapper_prepAllSubjects(subj, timepoints, eyeTrack)`: rasterizes the main experiment data. All arguments are optional. Without `subj` as an argument, all subjects' MEG data will be rasterized one by one. Passing a subject (e.g `'lilac04'`) will only rasterize that subject (this was in order to rasterize subjects in parallel on a cluster computer). The `timepoints` argument is to toggle between the normal time window and the long window. To rasterize the long window, pass `1:1401`. By default, it is `1:801`. The `eyetrack` argument is to rasterize eye data. Default is 0 for rasterizing MEG data, passing 1 will rasterize eye position data, and passing 2 will rasterize pupil diameter data. Raster files are saved in `/Intermediates_Study/Raster_Format/`

`wrapper_prepAllSubjectsTaskControl(subj,eyeTrack)`: rasterizes data from the second pilot experiment. Multiple sessions for a subject are not combined for the pilot, so 5 sets of raster files are created for each subject. To just rasterize one subject session, pass `subj` (e.g `'lilac03_sess02'`). The eye tracking argument works the same here as before.

`wrapper_prepAllSubjects(subjInd)`: in the Pilot0 directory, rasterizes data from the initial pilot. There are four subjects with just a single session, and `subjInd` is an optional parameter that must be between 1 and 4 and denotes which subject will be rasterized. Raster data is saved to `/MEG_Project2018/Pilot0/Raster_Format/`.

#### Preprocessing for ROI based decoding
On the 18 subjects from the main experiment, we also decoded from ROI sources. We did decoding analysis on 9 ROI's. The five atlas based ROI's are V1, V2, MT, precentral, and rostralmiddlefrontal. The four functional ROI's are based on contrasts we defined in an fMRI study (not described here). These contrasts were: Faces verus Objects (F-O), Scenes versus Objects (S-O), Scenes versus Scrambled Objects (S-SO), and Color versus Black/white (C-BW). The functional data is available upon request, but the ROI's in Brainstorm format are in anat.zip. The contents of this zip file should be extracted into `/MEG_Project2018/Intermediates_Data/anat/`

To decode from ROI sources, the MEG sensor data is converted to anatomical vertex data based on the Freesurfer surface for each ROI. The script to produce ROI sources is in `/PreprocessingCode/`:

`genAnatROI(subject,Atlas_Name)`: subject should be a cell array with the name of the subjects you want to produce ROI sources for (e.g `{lilac04}`). The `Atlas_Name` argument determines which ROI's sources will be created for. The options are: `'Desikan-Killiany'` for precentral and rostralmiddlefrontal, `'Brodmann'` for V1, V2, and MT, and `'fROIs'` for the four functional ROI's. The ROI sources are saved in `/MEG_Project2018/Intermediates_Study/ROI_Sources/`. They are not provided but can be produced with what has been provided.

The ROI sources are then converted to a raster format:

`wrapper_prepAllSubjects_ROI(ROI,subj)`: rasterizes ROI sources. `ROI` is a required argument and `subj` is optional like usual. Raster data is saved to `/Intermediates_Study/Raster_Format_ROI/`

#### Decoding

For the main experiment and the second pilot, the decoding analysis is initiated by running any of the scripts that start with a "submit" (e.g `submitSpiralIdentity_AttendHue.m`). Any scripts for ROI decoding will have the same names with '_ROI' appended.

Before running the submit scripts, edit `setupAnalysis.m` and `initializeDecodingParameters.m`. In `setupAnalysis.m`, edit `homeDir` to be wherever you placed the MEG_Project2018 directory. Set `eyePositionOpt` to 0 to decode using MEG sensors or 1 to decode using eye data. Use `classifierType` to choose which classifier from the neural decoding toolbox you want. `attentionCond` indicates whether decoding will be done on data taken when the subject was performing a hue or luminance matching task during the experiment. It can be 'HueCond' or 'LumCond'. The luminance matching task was only performed by the two subjects from the second pilot, so for decoding from main experiment data, `attentionCond` must be 'HueCond'.

In `initializeDecodingParameters.m`, you can specify a number of decoding parameters.
- `p.nFeat` is the number of sensors you want to use in the decoding analysis
- `p.decodingRuns` is the number of decoding runs that will be carried out. The final decoding accuracy will be averaged across this number of runs
- `p.num_cv_splits` is the number of cross-validation splits
- `p.reps_per_split` is how many trials for each label should appear in a CV split
- `p.nAvg` is the number of trial repetitions to average in each CV split (we always kept it equal to `p.reps_per_split`)
- `p.bin_width` is the size of each bin in milliseconds
- `p.temporal_cross_training` set to 0 to train and test at the same time points and to 1 to do temporal cross generalization decodingRuns`
- `p.longwindow` 0 or 1 toggles whether or not the longer time window will be used
- `p.powerAnalysis` 0 or 1 toggles whether normal or power analysis decoding will be done
- `p.powerRuns` array that gives the run numbers that are appended to the end of the results file for power analysis runs (ex. 6:10 would do 5 power analysis runs, the first results file would be ...6.mat and the fifth would be ...10.mat)
- `p.nullIterRange` array that gives the run numbers that are appended to the end of the null decoding runs, which are decoded if nullOpt is set to 0 in `setupAnalysis`. In null decoding, the decoding is performed on data that is shuffled

Before decoding happens, the raster data are converted to a binned format and saved in `/Intermediates_Study/Binned_Format/` (for the first pilot, in `/Pilot0/Binned_Format/`)

Generally, the decoding results are saved in `/Intermediates_Study/[classifier]/Results/[subject]/[problem]`. The decoding results are not included here. Instead, the results are consolidated into smaller files in `/Geometry/Quantitative_Data/` or in `/HueLum/Quantitative_Data/`. The scripts for doing that are mentioned in the other readme files.

More information on the decoding problems and on decoding from the first pilot data are in the geometry or huelum readme's.
