### Overview

This guide explains how to decode problems relevent to the geometry paper (Isabelle A. Rosenthal, Shridhar R. Singh, Katherine L Hermann, Dimitrios Pantazis, Bevil R Conway, Color Space Geometry Uncovered with Magnetoencephalography, Current Biology, 2020 November 16) and how to produce the figures in the paper.

Read README.md before reading this one.

### Decoding Problems

##### Spiral Identity
The spiral identity classifier trains on all eight spirals and tests on all eight spirals. Chance is therefore 1/8. This problem is run using `submitSpiralIdentity_AttendHue.m`. This function initiates decoding for one subject specified by the `subj` argument (e.g `'lilac04'`). There is also a second optional argument, `numTrials`. If passed, this argument overrides `p.num_cv_splits` and `p.nAvg`. Its inclusion was useful for running many power analysis runs in parallel more easily.

##### Spiral Identity Forced error
To run the forced error version of spiral identity, use `submitSpiralIdentityForcedError.m`. This function requires `subj` as an argument.

##### Color Term Decoding
To decode the identity of color terms, run `submitColorTermIdentity.m`. This requires `subj` as an argument.

##### Cross Temporal Decoding
In cross temporal decoding, the classifier is trained at each time bin and tested on all time bins. Any of the problems listed above can be decoded cross-temporally by editing `initializeDecodingParameters.m` so that `p.temporal_cross_training = 1`.

Cross temporal decoding was performed for spiral identity using 2 ms bins instead of 5 ms bins for figure 5.

##### Decoding Spirals and Terms
The function `submitTermsSpiralsCrosstraining.m` trains classifiers on color terms and tests on color spirals and vice versa. It does this at each luminance level, so it decodes four separate problems. These problems are decoded cross-temporally by default. The first argument is `subj` as usual, and the second argument `problem` is optional and specifies which of the four problems you want to decode. It must be a number between 1 and 4:
1. Train on terms, test on low luminance spirals
2. Train on terms, test on high luminance spirals
3. Train on low luminance spirals, test on terms
4. Train on high luminance spirals, test on terms

If it isn't provided, all four problems will be decoded one by one.

##### Decoding from Eye Data
To decode using eye data instead of MEG data, edit `setupAnalysis.m` so that `eyePositionOpt = 1`. Then edit `initializeDecodingParameters.m` to specify which eye data to decode from. To decode using pupil diameter, set `p.eyetrackingDesc` to `'PupilDiameter'` and change `p.nFeat = 2`. The number of features to decode from is two because there is a diameter for each eye. To decode using eye position, set `p.eyetrackingDesc` to `'EyePosition'` and change `p.nFeat = 4`. It must be four because there is an x and y position for each eye.

The raster files, binned files, and results of eye decoding are in `/Intermediates_Study/EyePositionDecoding/[eyeParam]/`

##### Long Window Decoding
Most of the analysis in the paper was done using a time window of [-200,600] ms. Later, we became curious about whether the spiral/terms cross decoding would yield interesting results at later time points, so we reprocessed the raw data with a time window of [-200,1200] ms. The directory structures of decoding with the long window is the same except '_LongWindow' is appended to the `Intermediates_Data`, `Raster_Format`, `Binned_Format`, and `Results` directories.

To decode using the long window, edit `intitializeDecodingParameters.m` so that `p.longWindow = 1`. We only used the long window for decoding term identity and doing the spiral/terms cross training because the runtimes were much longer.

##### Power Analysis
To test the data reliability, we did a power analysis. On each power analysis run, the decoding was run twice using independent sets of trials. We did this for varying numbers of trials per CV split, and we did 10 runs for each number of trials per split. To do power analysis runs, edit `initializeDecodingParameters.m` so that `p.powerAnalysis = 1`. Then specify the run numbers using `p.powerRuns`. For example, to do five runs, set `p.powerRuns = 1:5`. If later on you decide you want to do five more runs, you can set `p.powerRuns = 6:10`. For the power analysis, it's useful to use the optional second argument in `submitSpiralIdentity_AttendHue.m` to specify the number of trials per split in the function call. That way you can run it for multiple numbers of trials in parallel.
`
### Analyzing Decoding Results
The directory `/Geometry/Analysis_Code` contains scripts that produce each of the figures in the paper and the statistics. To run these, first edit `initializePaths` to point to the right places. You should only have to change `studyPath` to point to the `.../MEG_Project2018/` directory.

There are several scripts that start with `gather_` in the `Functions` directory. These are the scripts that grab all the decoding outputs and consolidate them in single files that are saved in `/Geometry/Quantitative_Data/[params]/`. These scripts are called automatically by the figure scripts when needed. The only scripts you need to run are the ones that start with `Fig` and `spiralID_stats.m`

### Color Naming Experiment
The directory with everything related to the color naming experiment done through Amazon Mechanical Turk is in the mTurk directory. The same experiment was also done with the main MEG participants before the scans, and this data is included in the Scan_Sessions directory.

#### Amazon Mechanical Turk
The raw data is located in `/mTurk/Experiment2/data_processing/raw_results/`. This data was preprocessed using a python script: `/mTurk/Experiment2/preprocess_mTurk_results.py`, which saves the processed results and other outputs in `/mTurk/Experiment2/data_processing/processed_results/`. These processed results are parsed and analyzed to determine the color naming concordance by the function `colorNamingConcordance.m` in the `Geometry/Analysis_Code/Functions/` directory. This function is automatically called by the Fig2F script, so no need to run it.

#### MEG Participant Data
The MEG participant color naming data is located in the `Scan_Sessions/[subject]` directory along with other notes about the scan sessions. These xlsx files are parsed and analyzed by the same functions as the mechanical turk data.
