function [trial,Time, name] = load_brainstorm_trials(brainstorm_db,protocol,subject,condition,channelname,lowpassfreq,weight)
% function [trial,Time] = load_trials(brainstorm_db,subject,conditions,channel)
%
% brainstorm_db: brainstorm database
% subject: subject name
% condition: conditions in brainstorm database
% data_type: 'MEG','GRAD','MAG','EEG', or 'MEG EEG' etc

%scale trials
if ~exist('weight')
    weight = 1;
end

%initialize
subjdir = fullfile(brainstorm_db,protocol,'data',subject);
trialdir = fullfile(subjdir,condition);

%find channel file
channeldir = fullfile(trialdir,'channel*'); %assume one channel file per run
fchannel = dir(channeldir);
if isempty(fchannel)
    channeldir = fullfile(subjdir,'/@default_study/','channel*'); %assume one channel file per subject
    fchannel = dir(channeldir);
    if isempty(fchannel)
        disp('No channel file could be detected');
        return
    end
end
Channel = load(fullfile(channeldir(1:end-9),fchannel.name));
Channel = Channel.Channel;

%find channelnames
for ch = 1:length(channelname)
    pos = strfind({Channel.Name},channelname{ch});
    ndx{ch} = find(~cellfun(@isempty,pos));
end
channelndx = unique([ndx{:}],'stable');

%find trial files
ftrials = dir(fullfile(trialdir,'*data*trial*'));

%remove bad trials from brainstorm
bststudy = load(fullfile(trialdir,'brainstormstudy.mat'));
ndx = [];
for i = 1:length(bststudy.BadTrials)
    pos = strfind({ftrials.name},bststudy.BadTrials{i});
    ndx(i) = find(~cellfun(@isempty,pos));
end
ftrials(ndx) = [];

name = {ftrials.name};
%load trials
for i = 1:length(ftrials)
    data = load(fullfile(trialdir,ftrials(i).name));
    trial{i} = data.F(channelndx,:)*weight;
    Time = data.Time;
end

%apply low pass filter
if exist('lowpassfreq') & lowpassfreq ~= 0 %if apply low pass filter
    order = max(100,round(length(Time)/10)); %keep one 10th of the timepoints as model order
    Fs = 1000; %hard set sampling frequency 1kHz
    h = filter_design('lowpass',lowpassfreq,order,Fs,0);
    
    parfor i = 1:length(ftrials)
        trial{i} = filter_apply(trial{i},h);
    end
    
end













