function [Accuracy] = onset_local_max_bootstrap_FDR_significance(data,time,nboot,nperm,significance_th,tail,bootsamples,chance)

numConsecutive = 5; %number of consecutive bins for onset determination
stimOnsetI = find(time==0);
%assign default 'right' tail
if ~exist('tail')
    tail = 'right';
end

if nargin < 8
    chance = 0;
end

data = data-chance;

%initialize
nobs = size(data,1); %length of observations
nvar = size(data,2); %number of variables

%compute onset and peak for original data
datam = mean(data,1);

%find significance and onset (run FDR analysis)
[StatMapPv,StatMap,PermFWER] = fl_permutation_1sample(data,nperm,significance_th,tail,'means');

[pthr,pcor,padj] = fdr(StatMapPv);

SignificantVariables = padj<significance_th;
sigTimePts = find(SignificantVariables == 1);

onsetInd = pullIndivOnset(sigTimePts, numConsecutive);
Accuracy.onset.orig = time(onsetInd);

Accuracy.mean = datam+chance;
Accuracy.th = SignificantVariables;
Accuracy.tndx = find(SignificantVariables>0);

%if no significant points in original data
if isempty(find(SignificantVariables))
    disp('No significant points found');
    Accuracy.tndx_onsetOnwards = [];
    return
else
    if ~isempty(onsetInd)
        Accuracy.tndx_onsetOnwards = find(SignificantVariables(onsetInd:end)>0)+onsetInd;
    else
        Accuracy.tndx_onsetOnwards = [];
        return
    end
end


%if no bootstrap samples requested (nboot=0), plot and return
if nboot == 0
    
    figure;hold on;
    plot(time,Accuracy.mean,'k','linewidth',2);
    w1 = min(Accuracy.mean);
    w2 = max(Accuracy.mean);
    w = w2 + 0.1*(w2-w1);
    Line.x = time(Accuracy.tndx);
    Line.y = w * ones(size(Line.x));
    plot(Line.x,Line.y,'k','linewidth',2);
    set(gca,'fontsize',20);
    grid on

    disp('Only significant points requested (no onset/peak)');
    return
    
end

%make bootstrap samples
if nargin < 7
    bootsamples = randi(nobs,nboot,nobs);
end

%compute onset and peak for bootstrap samples
tic
parfor i = 1:nboot
% for i = 1:nboot
    if rem(i,100) == 0 
        disp(['boot run ' num2str(i)]);
    end

    %create bootstrap sample
    databoot = data(bootsamples(i,:),:);
    databootm = mean(databoot,1);
    
    %find peak

    alldatabootm(i,:) = databootm;
    
    [StatMapPv,StatMap,PermFWER] = fl_permutation_1sample(databoot,nperm,significance_th,tail,'means');

    [pthr,pcor,padj] = fdr(StatMapPv(stimOnsetI:end));
    padj_tmp = ones(size(time));
    padj_tmp(stimOnsetI:end) = padj;
    padj = padj_tmp;

    SignificantVariables = padj<significance_th;
    sigTimePts = find(SignificantVariables == 1);

    onsetInd = pullIndivOnset(sigTimePts, numConsecutive)
    onset_tmp = time(onsetInd)

   
    %if significant points have been found
    if ~isempty(onset_tmp)
        onset(i) = onset_tmp;
    else
        onset(i) = nan;
    end
    
    thBoot(i,:) = SignificantVariables;
    
end
toc
%remove nan points
onset_all = onset;
onset_all(isnan(onset)) = 600;
onset(isnan(onset))=[];

Accuracy.sigBoot.th = thBoot;

%sort
onsetSort = sort(onset);
alldatabootmSort = sort(alldatabootm,1);
%estimate 95% confidence intervals
    
Accuracy.timecourse.boot = alldatabootm+chance;
Accuracy.timecourse.bootmean = mean((alldatabootm),1)+chance;

if length(onset)>=100
    n1 = ceil(length(onset)*0.025);
    n2 = floor(length(onset)*0.975);
    onset95(1) = onsetSort(n1);
    onset95(2) = onsetSort(n2);
    Accuracy.onset.boot = onset;
    Accuracy.onset.boot_all = onset_all;
    Accuracy.onset.confidence95 = onset95;
else
    disp('Not enough points for onset 95% confidence interval');
end







