function [Accuracy] = onset_bootstrap_FDR_significance(data,time,nboot,nperm,significance_th,tail,bootsamples,chance)

numConsecutive = 4; %number of consecutive bins for onset determination
stimOnsetI = find(time==0);
%assign default 'right' tail
if ~exist('tail')
    tail = 'right';
end

if nargin < 8
    chance = 0;
end

data = data-chance;

%initialize
nobs = size(data,1); %length of observations
nvar = size(data,2); %number of variables

%compute onset and peak for original data
%find peak
datam = mean(data,1);

[SignificantVariables,~,~,~] = fl_permutation_cluster_1sample(data,nperm,0.01,significance_th,tail,'means');
SignificantVariables = SignificantVariables';

sigTimePts = find(SignificantVariables == 1);

onsetInd = pullIndivOnset(sigTimePts, numConsecutive);

Accuracy.onset.orig = time(onsetInd);

Accuracy.mean = datam+chance;
Accuracy.th = SignificantVariables;
Accuracy.tndx = find(SignificantVariables>0);

%if no significant points in original data
if isempty(find(SignificantVariables))
    disp('No significant points found');
    Accuracy.tndx_onsetOnwards = [];
    return
else
    if ~isempty(onsetInd)
        Accuracy.tndx_onsetOnwards = find(SignificantVariables(onsetInd:end)>0)+onsetInd;
    else
        Accuracy.tndx_onsetOnwards = [];
        return
    end
end


%if no bootstrap samples requested (nboot=0), plot and return
if nboot == 0
    
    figure;hold on;
    plot(time,Accuracy.mean,'k','linewidth',2);
    w1 = min(Accuracy.mean);
    w2 = max(Accuracy.mean);
    w = w2 + 0.1*(w2-w1);
    Line.x = time(Accuracy.tndx);
    Line.y = w * ones(size(Line.x));
    plot(Line.x,Line.y,'k','linewidth',2);
    set(gca,'fontsize',20);
    grid on

    disp('Only significant points requested (no onset/peak)');
    return
    
end

%make bootstrap samples
if nargin < 7
    bootsamples = randi(nobs,nboot,nobs);
end

%compute onset and peak for bootstrap samples
tndxBoot = zeros(nboot,numel(time));
tndx_onsetOnwardsBoot = zeros(nboot,numel(time));
tic
parfor i = 1:nboot
% for i = 1:nboot
    if rem(i,100) == 0 
        disp(['boot run ' num2str(i)]);
    end
    
    %create bootstrap sample
    databoot = data(bootsamples(i,:),:);
    databootm = mean(databoot,1);
    
    %find peak

    alldatabootm(i,:) = databootm;

    [SignificantVariables,~,~,~] = fl_permutation_cluster_1sample(databoot,nperm,0.01,significance_th,tail,'means');
    SignificantVariables = SignificantVariables';
    
    sigTimePts = find(SignificantVariables(stimOnsetI:end) == 1) + stimOnsetI - 1;

    onsetInd = pullIndivOnset(sigTimePts, numConsecutive);
    
   
    %if significant points have been found
    if ~isempty(onsetInd)
        onset(i) = time(onsetInd);
    else
        onset(i) = nan;
    end
    
    thBoot(i,:) = SignificantVariables;
    
end
toc
%remove nan points
onset_all = onset;
onset_all(isnan(onset)) = 600;
onset(isnan(onset))=[];

Accuracy.sigBoot.th = thBoot;

%sort
onsetSort = sort(onset);
alldatabootmSort = sort(alldatabootm,1);
%estimate 95% confidence intervals
    
Accuracy.timecourse.boot = alldatabootm+chance;
Accuracy.timecourse.bootmean = mean((alldatabootm),1)+chance;

if length(onset)>=100
    n1 = ceil(length(onset)*0.025);
    n2 = floor(length(onset)*0.975);
    onset95(1) = onsetSort(n1);
    onset95(2) = onsetSort(n2);
    Accuracy.onset.boot = onset;
    Accuracy.onset.boot_all = onset_all;
    Accuracy.onset.confidence95 = onset95;
else
    disp('Not enough points for onset 95% confidence interval');
end







