function [Accuracy] = onset_local_max_bootstrap_FDR_significance(data,time,nboot,nperm,significance_th,tail,bootsamples,peakWindow,chance)
% function [Accuracy] = onset_peak_bootstrap_cluster_significance(data,time,nboot,nperm,cluster_definition_th,significance_th,tail)
%
% data: data: observations x variable (i.e. subject x time) 
%time = index of times for data
%peakWindow if you want to look at the peaks in only a restricted time
%window

numConsecutive = 5; %number of consecutive bins for onset determination
stimOnsetI = find(time==0);
%assign default 'right' tail
if ~exist('tail')
    tail = 'right';
end

if nargin < 9
    chance = 0;
end

data = data-chance;

%initialize
nobs = size(data,1); %length of observations
nvar = size(data,2); %number of variables

%compute onset and peak for original data
%find peak
%datam = fl_cell_mean(data);
datam = mean(data,1);

if nargin < 8
   peakWindow = [1,numel(datam)]; 
end

[orig_peak,I] = find_local_maxima(datam,peakWindow);

Accuracy.peak.orig = time(I);
%find significance and onset (run FDR analysis)
%[accuracy_th, clusters,clustersize,StatMapPermPV] = permutation_cluster_1sample_alld(data, nperm, cluster_definition_th, significance_th,tail); %data is observations x variable
%[SignificantVariables,SignificantVariables_weighted,clustersize,clustersize_weighted] = fl_permutation_cluster_1sample(data, nperm, cluster_th, significance_th,tail);
[StatMapPv,StatMap,PermFWER] = fl_permutation_1sample(data,nperm,significance_th,tail,'means');

[pthr,pcor,padj] = fdr(StatMapPv);

SignificantVariables = padj<significance_th;
sigTimePts = find(SignificantVariables == 1);

onsetInd = pullIndivOnset(sigTimePts, numConsecutive);
Accuracy.onset.orig = time(onsetInd);


%Accuracy.onset.orig = time(min(find(SignificantVariables)));
Accuracy.mean = datam+chance;
Accuracy.th = SignificantVariables;
Accuracy.tndx = find(SignificantVariables>0);

%if no significant points in original data
if isempty(find(SignificantVariables))
    disp('No significant points found');
    Accuracy.tndx_onsetOnwards = [];
    return
else
    if ~isempty(onsetInd)
        Accuracy.tndx_onsetOnwards = find(SignificantVariables(onsetInd:end)>0)+onsetInd;
    else
        Accuracy.tndx_onsetOnwards = [];
        return
    end
end


%if no bootstrap samples requested (nboot=0), plot and return
if nboot == 0
    
    figure;hold on;
    plot(time,Accuracy.mean,'k','linewidth',2);
    w1 = min(Accuracy.mean);
    w2 = max(Accuracy.mean);
    w = w2 + 0.1*(w2-w1);
    Line.x = time(Accuracy.tndx);
    Line.y = w * ones(size(Line.x));
    plot(Line.x,Line.y,'k','linewidth',2);
    set(gca,'fontsize',20);
    grid on

    disp('Only significant points requested (no onset/peak)');
    return
    
end

%make bootstrap samples
if nargin < 7
    bootsamples = randi(nobs,nboot,nobs);
end

%compute onset and peak for bootstrap samples
nargs = nargin;
tic
parfor i = 1:nboot
% for i = 1:nboot
    if rem(i,100) == 0 
        disp(['boot run ' num2str(i)]);
    end
%     if ~rem(i,200)
%         disp(['Process bootstrap samples: ' num2str(i) ' out of ' num2str(nboot)]);
%     end
    
    %create bootstrap sample
    databoot = data(bootsamples(i,:),:);
    databootm = mean(databoot,1);
    
    %find peak

    [peak_val(i),I] = find_local_maxima(databootm,peakWindow);
    peak(i) = time(I);
    alldatabootm(:,i) = databootm;
    %onset (run cluster analysis)
    %[accuracy_th, clusters,clustersize,StatMapPermPV] = permutation_cluster_1sample_alld(databoot, nperm, cluster_definition_th, significance_th,tail); %data is observations x variable
   % [SignificantVariables,SignificantVariables_weighted,clustersize,clustersize_weighted] = fl_permutation_cluster_1sample(data, nperm, cluster_th, significance_th,tail);
% [StatMapPv,StatMap,PermFWER] = fl_permutation_1sample(databoot(:,stimOnsetI:end),nperm,significance_th,tail,'means');
% [StatMapPv,StatMap,PermFWER] = fl_permutation_1sample(databoot(:,stimOnsetI:end),nperm,significance_th,tail,'means');
[StatMapPv,StatMap,PermFWER] = fl_permutation_1sample(databoot,nperm,significance_th,tail,'means');

[pthr,pcor,padj] = fdr(StatMapPv(stimOnsetI:end));
padj_tmp = ones(size(time));
padj_tmp(stimOnsetI:end) = padj;
padj = padj_tmp;

SignificantVariables = padj<significance_th;
sigTimePts = find(SignificantVariables == 1);

onsetInd = pullIndivOnset(sigTimePts, numConsecutive)
onset_tmp = time(onsetInd)

   
    %if significant points have been found
  %  onset_tmp = time(min(find(SignificantVariables)));
    if ~isempty(onset_tmp)
        onset(i) = onset_tmp;
    else
        onset(i) = nan;
    end
    
    thBoot(i,:) = SignificantVariables;
    
end
toc
%remove nan points
onset_all = onset;
onset_all(isnan(onset)) = 600;
onset(isnan(onset))=[];

Accuracy.sigBoot.th = thBoot;

%sort
peakSort = sort(peak);
onsetSort = sort(onset);
peak_valSort = sort(peak_val);
alldatabootmSort = sort(alldatabootm,2);
%estimate 95% confidence intervals
if length(peak)>=100
    n1 = ceil(length(peak)*0.025);
    n2 = floor(length(peak)*0.975);
    peak95(1) = peakSort(n1);
    peak95(2) = peakSort(n2);
    Accuracy.peak.boot = peak;
    Accuracy.peak.confidence95 = peak95;
    Accuracy.peakValue.confidence95 = [peak_valSort(n1) peak_valSort(n2)]+chance;
    Accuracy.peakValue.orig = orig_peak+chance;
    Accuracy.peakValue.boot = peak_val+chance;
    Accuracy.timecourse.boot = alldatabootm+chance;
    Accuracy.timecourse.bootmean = mean((alldatabootm),2)+chance;
    [Accuracy.timecourse.peakValue,I] = find_local_maxima(Accuracy.timecourse.bootmean,peakWindow);
    Accuracy.timecourse.peakValue = Accuracy.timecourse.peakValue+chance;
    Accuracy.timecourse.peak = time(I);
else
    disp('Not enough points for peak 95% confidence interval');
end
if length(peak)>=100
    n1 = ceil(length(onset)*0.025);
    n2 = floor(length(onset)*0.975);
    onset95(1) = onsetSort(n1);
    onset95(2) = onsetSort(n2);
    Accuracy.onset.boot = onset;
    Accuracy.onset.boot_all = onset_all;
    Accuracy.onset.confidence95 = onset95;
else
    disp('Not enough points for onset 95% confidence interval');
end







