
function [onset, indivOnsets, numNotSig, outStruct] = pullMeanOfOnsets(sigMatrix, binStarts, outStruct)

% INPUTS: sigMatrix (subjects x timepoints binary matrix in which '1'
%                    indicates significant at p < 0.05 (corrected))
%         binStarts (time in ms relative to stim onset of this bin's start)
%
% OUTPUTS: onset    (time in ms of avg onset of significance across subjects)
%

numConsecutive = 2;

numSubjs = size(sigMatrix, 1);
indivOnsets = [];
for s = 1 : numSubjs
    sigTimePts = find(sigMatrix(s, :) == 1);
    onsetInd = pullIndivOnset(sigTimePts, numConsecutive);
    binStarts(onsetInd)
    if ~isempty(onsetInd)
        indivOnsets = [indivOnsets, binStarts(onsetInd)];
        outStruct.indivOnset(s) = binStarts(onsetInd);
    else
        outStruct.indivOnset(s) = NaN;
    end
    
end

%onset = round(mean(indivOnsets));
onset = median(indivOnsets);
if numel(indivOnsets) < numSubjs
    numNotSig = numSubjs - numel(indivOnsets);
    disp('Error: Not all subjects reached significance')
else
    numNotSig = 0;
end

end